Debug

Trait Debug 

1.0.0 · Source
pub trait Debug {
    // Required method
    fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>;
}
? formatting.

Debug should format the output in a programmer-facing, debugging context.

Generally speaking, you should just derive a Debug implementation.

When used with the alternate format specifier #?, the output is pretty-printed.

For more information on formatters, see the module-level documentation.

This trait can be used with #[derive] if all fields implement Debug. When derived for structs, it will use the name of the struct, then {, then a comma-separated list of each field’s name and Debug value, then }. For enums, it will use the name of the variant and, if applicable, (, then the Debug values of the fields, then ).

Stability

Derived Debug formats are not stable, and so may change with future Rust versions. Additionally, Debug implementations of types provided by the standard library (std, core, alloc, etc.) are not stable, and may also change with future Rust versions.

Examples

Deriving an implementation:

#[derive(Debug)]
struct Point {
    x: i32,
    y: i32,
}

let origin = Point { x: 0, y: 0 };

assert_eq!(
    format!("The origin is: {origin:?}"),
    "The origin is: Point { x: 0, y: 0 }",
);

Manually implementing:

use std::fmt;

struct Point {
    x: i32,
    y: i32,
}

impl fmt::Debug for Point {
    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
        f.debug_struct("Point")
         .field("x", &self.x)
         .field("y", &self.y)
         .finish()
    }
}

let origin = Point { x: 0, y: 0 };

assert_eq!(
    format!("The origin is: {origin:?}"),
    "The origin is: Point { x: 0, y: 0 }",
);

There are a number of helper methods on the Formatter struct to help you with manual implementations, such as debug_struct.

Types that do not wish to use the standard suite of debug representations provided by the Formatter trait (debug_struct, debug_tuple, debug_list, debug_set, debug_map) can do something totally custom by manually writing an arbitrary representation to the Formatter.

impl fmt::Debug for Point {
    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
        write!(f, "Point [{} {}]", self.x, self.y)
    }
}

Debug implementations using either derive or the debug builder API on Formatter support pretty-printing using the alternate flag: {:#?}.

Pretty-printing with #?:

#[derive(Debug)]
struct Point {
    x: i32,
    y: i32,
}

let origin = Point { x: 0, y: 0 };

let expected = "The origin is: Point {
    x: 0,
    y: 0,
}";
assert_eq!(format!("The origin is: {origin:#?}"), expected);

Required Methods

1.0.0 · Source

fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>

Formats the value using the given formatter.

Errors

This function should return Err if, and only if, the provided Formatter returns Err. String formatting is considered an infallible operation; this function only returns a Result because writing to the underlying stream might fail and it must provide a way to propagate the fact that an error has occurred back up the stack.

Examples
use std::fmt;

struct Position {
    longitude: f32,
    latitude: f32,
}

impl fmt::Debug for Position {
    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
        f.debug_tuple("")
         .field(&self.longitude)
         .field(&self.latitude)
         .finish()
    }
}

let position = Position { longitude: 1.987, latitude: 2.983 };
assert_eq!(format!("{position:?}"), "(1.987, 2.983)");

assert_eq!(format!("{position:#?}"), "(
    1.987,
    2.983,
)");

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl Debug for !

1.0.0 · Source

impl Debug for ()

Source

impl Debug for Abi

1.26.0 · Source

impl Debug for AccessError

1.0.0 · Source

impl Debug for AddrParseError

Source

impl Debug for AidokuError

Source

impl Debug for core::mem::alignment::Alignment

1.28.0 · Source

impl Debug for aidoku::alloc::fmt::Alignment

Source

impl Debug for core::alloc::AllocError



impl Debug for AllocError

Source

impl Debug for Always

Source

impl Debug for AncillaryError

1.16.0 · Source

impl Debug for Args

1.16.0 · Source

impl Debug for ArgsOs

1.0.0 · Source

impl Debug for Arguments<'_>

Source

impl Debug for Array

Source

impl Debug for AsciiChar

Source

impl Debug for Assume

1.3.0 · Source

impl Debug for Atomic<bool>

Available on target_has_atomic_load_store=8 only.
1.34.0 · Source

impl Debug for Atomic<i8>

1.34.0 · Source

impl Debug for Atomic<i16>

1.34.0 · Source

impl Debug for Atomic<i32>

1.34.0 · Source

impl Debug for Atomic<i64>

1.3.0 · Source

impl Debug for Atomic<isize>

1.34.0 · Source

impl Debug for Atomic<u8>

1.34.0 · Source

impl Debug for Atomic<u16>

1.34.0 · Source

impl Debug for Atomic<u32>

1.34.0 · Source

impl Debug for Atomic<u64>

1.3.0 · Source

impl Debug for Atomic<usize>

Source

impl Debug for AtomicOrdering

1.65.0 · Source

impl Debug for Backtrace

Source

impl Debug for BacktraceFrame

1.65.0 · Source

impl Debug for BacktraceStatus

Source

impl Debug for BacktraceStyle

1.16.0 · Source

impl Debug for Barrier

1.16.0 · Source

impl Debug for BarrierWaitResult



impl Debug for BigEndian

Source

impl Debug for Bool



impl Debug for BoolVector2D



impl Debug for BoolVector3D

1.13.0 · Source

impl Debug for BorrowError

1.13.0 · Source

impl Debug for BorrowMutError

1.63.0 · Source

impl Debug for BorrowedFd<'_>

1.0.0 · Source

impl Debug for Builder

Source

impl Debug for ButtonSetting

Source

impl Debug for ByteStr

Source

impl Debug for ByteString

1.3.0 · Source

impl Debug for CStr

Shows the underlying bytes as a normal string, with invalid UTF-8 presented as hex escape sequences.

1.0.0 · Source

impl Debug for CString

Delegates to the CStr implementation of fmt::Debug, showing invalid UTF-8 as hex escapes.

Source

impl Debug for Canvas

Source

impl Debug for CanvasError

Source

impl Debug for Chapter

Source

impl Debug for Char

Source

impl Debug for CharCase

1.34.0 · Source

impl Debug for CharTryFromError

1.38.0 · Source

impl Debug for Chars<'_>

Source

impl Debug for CheckFilter

1.16.0 · Source

impl Debug for Child

1.16.0 · Source

impl Debug for ChildStderr

1.16.0 · Source

impl Debug for ChildStdin

1.16.0 · Source

impl Debug for ChildStdout

Source

impl Debug for Color

1.0.0 · Source

impl Debug for Command

Source

impl Debug for CommandResolvedEnvs

1.13.0 · Source

impl Debug for Components<'_>

Source

impl Debug for std::sync::nonpoison::condvar::Condvar

1.16.0 · Source

impl Debug for std::sync::poison::condvar::Condvar

Source

impl Debug for Const

Source

impl Debug for ContentRating

1.36.0 · Source

impl Debug for Context<'_>

1.27.0 · Source

impl Debug for CpuidResult

Source

impl Debug for DebugAsHex



impl Debug for DecodeError



impl Debug for DecodeReport

1.9.0 · Source

impl Debug for DecodeUtf16Error



impl Debug for DecoderState

Source

impl Debug for DeepLinkResult



impl Debug for DefaultHashBuilder

1.7.0 · Source

impl Debug for DefaultHasher



impl Debug for DestBufTooSmallError

Source

impl Debug for Dir

1.6.0 · Source

impl Debug for DirBuilder

1.13.0 · Source

impl Debug for DirEntry

1.87.0 · Source

impl Debug for std::ffi::os_str::Display<'_>

1.0.0 · Source

impl Debug for std::path::Display<'_>

1.17.0 · Source

impl Debug for aidoku::alloc::string::Drain<'_>

1.27.0 · Source

impl Debug for Duration

Source

impl Debug for DynTrait

Source

impl Debug for DynTraitPredicate

Source

impl Debug for EditableListSetting

1.0.0 · Source

impl Debug for aidoku::alloc::io::Empty

1.17.0 · Source

impl Debug for EncodeUtf16<'_>



impl Debug for EncoderState

Source

impl Debug for Enum

1.0.0 · Source

impl Debug for aidoku::alloc::io::Error

1.0.0 · Source

impl Debug for aidoku::alloc::fmt::Error

Source

impl Debug for serde_core::de::value::Error



impl Debug for Error

1.0.0 · Source

impl Debug for ErrorKind

1.20.0 · Source

impl Debug for core::char::EscapeDebug

1.16.0 · Source

impl Debug for core::ascii::EscapeDefault

1.0.0 · Source

impl Debug for core::char::EscapeDefault

1.0.0 · Source

impl Debug for core::char::EscapeUnicode

1.61.0 · Source

impl Debug for ExitCode

1.0.0 · Source

impl Debug for ExitStatus

Source

impl Debug for ExitStatusError

Source

impl Debug for Field

Source

impl Debug for FieldId

1.0.0 · Source

impl Debug for File

1.75.0 · Source

impl Debug for FileTimes

1.16.0 · Source

impl Debug for FileType

Source

impl Debug for aidoku::Filter

Source

impl Debug for FilterItem

Source

impl Debug for FilterKind

Source

impl Debug for FilterValue



impl Debug for FixedState



impl Debug for FixedState

Source

impl Debug for Float

Source

impl Debug for FloatErrorKind

Source

impl Debug for FnPtr

Source

impl Debug for Font

Source

impl Debug for FontWeight

Source

impl Debug for FormattingOptions

1.0.0 · Source

impl Debug for FpCategory

1.69.0 · Source

impl Debug for FromBytesUntilNulError

1.64.0 · Source

impl Debug for FromBytesWithNulError

1.0.0 · Source

impl Debug for FromUtf8Error

1.0.0 · Source

impl Debug for FromUtf16Error

1.64.0 · Source

impl Debug for FromVecWithNulError

Source

impl Debug for Generic

Source

impl Debug for GenericType

1.86.0 · Source

impl Debug for GetDisjointMutError

Source

impl Debug for alloc::alloc::Global



impl Debug for Global

Source

impl Debug for GroupSetting

Source

impl Debug for HomeComponent

Source

impl Debug for HomeComponentValue

Source

impl Debug for HomeLayout

Source

impl Debug for HomePartialResult

Source

impl Debug for Html

Source

impl Debug for HtmlError

Source

impl Debug for HttpMethod

Source

impl Debug for IgnoredAny

Source

impl Debug for ImageRef

Source

impl Debug for ImageRequest

Source

impl Debug for ImageResponse

1.34.0 · Source

impl Debug for Infallible

1.8.0 · Source

impl Debug for Instant

Source

impl Debug for Int

1.55.0 · Source

impl Debug for IntErrorKind

Source

impl Debug for IntoChars

Source

impl Debug for IntoIncoming

1.64.0 · Source

impl Debug for IntoStringError

1.7.0 · Source

impl Debug for IpAddr

1.0.0 · Source

impl Debug for Ipv4Addr

1.0.0 · Source

impl Debug for Ipv6Addr

Source

impl Debug for Ipv6MulticastScope

1.13.0 · Source

impl Debug for std::path::Iter<'_>

1.0.0 · Source

impl Debug for JoinPathsError

Source

impl Debug for JsError

Source

impl Debug for Kind

Source

impl Debug for Last

1.28.0 · Source

impl Debug for Layout

1.50.0 · Source

impl Debug for LayoutError

Source

impl Debug for Lifetime

Source

impl Debug for LineCap

Source

impl Debug for LineJoin

Source

impl Debug for LinkSetting

Source

impl Debug for LinkValue



impl Debug for LinkedIndexU8



impl Debug for LinkedIndexU16



impl Debug for LinkedIndexUsize

Source

impl Debug for Listing

Source

impl Debug for ListingKind



impl Debug for LittleEndian

Source

impl Debug for LocalWaker

Source

impl Debug for Locality

1.10.0 · Source

impl Debug for Location<'_>

Source

impl Debug for LoginMethod

Source

impl Debug for LoginSetting

Source

impl Debug for Manga

Source

impl Debug for MangaPageResult

Source

impl Debug for MangaStatus

Source

impl Debug for MangaWithChapter

1.16.0 · Source

impl Debug for Metadata

Source

impl Debug for MultiSelectFilter

Source

impl Debug for MultiSelectSetting

Source

impl Debug for NormalizeError

1.64.0 · Source

impl Debug for NulError

Source

impl Debug for OnSuccess

Source

impl Debug for OnUnwind

1.16.0 · Source

impl Debug for std::sync::once::Once

1.16.0 · Source

impl Debug for OnceState

1.0.0 · Source

impl Debug for OpenOptions

1.0.0 · Source

impl Debug for core::cmp::Ordering

1.0.0 · Source

impl Debug for core::sync::atomic::Ordering

1.0.0 · Source

impl Debug for OsStr

1.0.0 · Source

impl Debug for OsString

1.7.0 · Source

impl Debug for Output

1.63.0 · Source

impl Debug for OwnedFd

Source

impl Debug for Page

Source

impl Debug for PageContent

Source

impl Debug for PageIcon

Source

impl Debug for PageSetting

1.81.0 · Source

impl Debug for PanicMessage<'_>

1.0.0 · Source

impl Debug for ParseBoolError

1.20.0 · Source

impl Debug for ParseCharError

1.0.0 · Source

impl Debug for core::num::float_parse::ParseFloatError

Source

impl Debug for num_traits::ParseFloatError

1.0.0 · Source

impl Debug for ParseIntError

1.0.0 · Source

impl Debug for std::path::Path

Source

impl Debug for aidoku::canvas::Path

1.0.0 · Source

impl Debug for PathBuf

Source

impl Debug for PathBuilder

Source

impl Debug for PathOp

1.0.0 · Source

impl Debug for Permissions

Source

impl Debug for PhantomContravariantLifetime<'_>

Source

impl Debug for PhantomCovariantLifetime<'_>

Source

impl Debug for PhantomInvariantLifetime<'_>

1.33.0 · Source

impl Debug for PhantomPinned

Source

impl Debug for PickerSetting

Source

impl Debug for PidFd

1.87.0 · Source

impl Debug for PipeReader

1.87.0 · Source

impl Debug for PipeWriter

Source

impl Debug for Point

Source

impl Debug for Pointer

Source

impl Debug for QueryParameters

1.16.0 · Source

impl Debug for std::hash::random::RandomState



impl Debug for RandomState



impl Debug for RandomState

Source

impl Debug for RangeFilter

1.0.0 · Source

impl Debug for RangeFull

1.36.0 · Source

impl Debug for RawWaker

1.36.0 · Source

impl Debug for RawWakerVTable

1.0.0 · Source

impl Debug for ReadDir

Source

impl Debug for aidoku::canvas::Rect

1.0.0 · Source

impl Debug for RecvError

1.12.0 · Source

impl Debug for std::sync::mpsc::RecvTimeoutError

Source

impl Debug for Reference

1.16.0 · Source

impl Debug for aidoku::alloc::io::Repeat

Source

impl Debug for aidoku::imports::net::Request

Source

impl Debug for RequestError

Source

impl Debug for Response

1.63.0 · Source

impl Debug for Scope<'_, '_>

Source

impl Debug for SearchStep



impl Debug for SeedableRandomState



impl Debug for SeedableRandomState

1.0.0 · Source

impl Debug for SeekFrom

Source

impl Debug for SegmentSetting

Source

impl Debug for SelectFilter

Source

impl Debug for SelectSetting

Source

impl Debug for SerializeError

Source

impl Debug for Setting

Source

impl Debug for SettingValue



impl Debug for SharedSeed

1.0.0 · Source

impl Debug for Shutdown

Source

impl Debug for Sign

Source

impl Debug for SimdAlign

1.0.0 · Source

impl Debug for Sink

1.0.0 · Source

impl Debug for SipHasher

Source

impl Debug for Slice

1.0.0 · Source

impl Debug for core::net::socket_addr::SocketAddr

1.10.0 · Source

impl Debug for std::os::unix::net::addr::SocketAddr

1.0.0 · Source

impl Debug for SocketAddrV4

1.0.0 · Source

impl Debug for SocketAddrV6

Source

impl Debug for SortFilter

Source

impl Debug for SortFilterDefault



impl Debug for Span

1.16.0 · Source

impl Debug for SplitPaths<'_>

Source

impl Debug for StdError

1.16.0 · Source

impl Debug for Stderr

1.16.0 · Source

impl Debug for StderrLock<'_>

1.16.0 · Source

impl Debug for Stdin

1.16.0 · Source

impl Debug for StdinLock<'_>

1.16.0 · Source

impl Debug for Stdio

1.16.0 · Source

impl Debug for Stdout

1.16.0 · Source

impl Debug for StdoutLock<'_>

Source

impl Debug for StepperSetting

Source

impl Debug for Str

1.0.0 · Source

impl Debug for aidoku::alloc::String

1.7.0 · Source

impl Debug for StripPrefixError

Source

impl Debug for StrokeStyle

Source

impl Debug for Struct

1.28.0 · Source

impl Debug for System

Source

impl Debug for SystemRng

1.8.0 · Source

impl Debug for SystemTime

1.8.0 · Source

impl Debug for SystemTimeError

1.0.0 · Source

impl Debug for TcpListener

1.0.0 · Source

impl Debug for TcpStream

Source

impl Debug for TextFilter

Source

impl Debug for TextSetting

1.0.0 · Source

impl Debug for Thread

1.19.0 · Source

impl Debug for ThreadId

Source

impl Debug for ToCasefold

1.0.0 · Source

impl Debug for ToLowercase

Source

impl Debug for ToTitlecase

1.0.0 · Source

impl Debug for ToUppercase

Source

impl Debug for ToggleSetting

Source

impl Debug for Trait

1.59.0 · Source

impl Debug for TryFromCharError

1.66.0 · Source

impl Debug for TryFromFloatSecsError

1.34.0 · Source

impl Debug for TryFromIntError

1.34.0 · Source

impl Debug for TryFromSliceError

1.89.0 · Source

impl Debug for std::fs::TryLockError

1.0.0 · Source

impl Debug for std::sync::mpsc::TryRecvError

1.57.0 · Source

impl Debug for aidoku::alloc::collections::TryReserveError



impl Debug for TryReserveError



impl Debug for TryReserveError

Source

impl Debug for aidoku::alloc::collections::TryReserveErrorKind



impl Debug for TryReserveErrorKind

Source

impl Debug for Tuple

Source

impl Debug for Type

1.0.0 · Source

impl Debug for TypeId

Source

impl Debug for TypeKind

Source

impl Debug for UCred

1.0.0 · Source

impl Debug for UdpSocket

Source

impl Debug for core::mem::type_info::Union

1.10.0 · Source

impl Debug for UnixDatagram

1.10.0 · Source

impl Debug for UnixListener

1.10.0 · Source

impl Debug for UnixStream



impl Debug for UnknownUnit

Source

impl Debug for UnorderedKeyError

Source

impl Debug for UpdateStrategy

1.79.0 · Source

impl Debug for Utf8Chunks<'_>

1.0.0 · Source

impl Debug for Utf8Error

Source

impl Debug for VaList<'_>

1.0.0 · Source

impl Debug for VarError

Source

impl Debug for Variant

1.16.0 · Source

impl Debug for Vars

1.16.0 · Source

impl Debug for VarsOs

Source

impl Debug for Viewer

1.5.0 · Source

impl Debug for WaitTimeoutResult

1.36.0 · Source

impl Debug for Waker

Source

impl Debug for WouldBlock

1.56.0 · Source

impl Debug for WriterPanicked

Source

impl Debug for XdgDirsIter

1.27.0 · Source

impl Debug for __m128

1.27.0 · Source

impl Debug for __m256

1.72.0 · Source

impl Debug for __m512

1.89.0 · Source

impl Debug for __m128bh

1.27.0 · Source

impl Debug for __m128d

1.94.0 · Source

impl Debug for __m128h

1.27.0 · Source

impl Debug for __m128i

1.89.0 · Source

impl Debug for __m256bh

1.27.0 · Source

impl Debug for __m256d

1.94.0 · Source

impl Debug for __m256h

1.27.0 · Source

impl Debug for __m256i

1.89.0 · Source

impl Debug for __m512bh

1.72.0 · Source

impl Debug for __m512d

1.94.0 · Source

impl Debug for __m512h

1.72.0 · Source

impl Debug for __m512i

Source

impl Debug for __tile1024i

Source

impl Debug for bf16

1.0.0 · Source

impl Debug for bool

1.16.0 · Source

impl Debug for c_void

1.0.0 · Source

impl Debug for char

1.0.0 · Source

impl Debug for dyn Any

1.0.0 · Source

impl Debug for dyn Any + Send

1.28.0 · Source

impl Debug for dyn Any + Send + Sync

1.0.0 · Source

impl Debug for f16

1.0.0 · Source

impl Debug for f32

1.0.0 · Source

impl Debug for f64

1.0.0 · Source

impl Debug for f128

1.0.0 · Source

impl Debug for i8

1.0.0 · Source

impl Debug for i16

1.0.0 · Source

impl Debug for i32

1.0.0 · Source

impl Debug for i64

1.0.0 · Source

impl Debug for i128

1.0.0 · Source

impl Debug for isize

1.0.0 · Source

impl Debug for str

1.0.0 · Source

impl Debug for u8

1.0.0 · Source

impl Debug for u16

1.0.0 · Source

impl Debug for u32

1.0.0 · Source

impl Debug for u64

1.0.0 · Source

impl Debug for u128

1.0.0 · Source

impl Debug for usize

Source

impl<'a, 'b, const N: usize> Debug for CharArrayRefSearcher<'a, 'b, N>

Source

impl<'a, 'b> Debug for CharSliceSearcher<'a, 'b>

Source

impl<'a, 'b> Debug for StrSearcher<'a, 'b>

1.0.0 · Source

impl<'a, A> Debug for core::option::Iter<'a, A>
where A: Debug + 'a,

1.0.0 · Source

impl<'a, A> Debug for core::option::IterMut<'a, A>
where A: Debug + 'a,

Source

impl<'a, E> Debug for BytesDeserializer<'a, E>

Source

impl<'a, E> Debug for CowStrDeserializer<'a, E>

Available on crate features alloc or std only.
Source

impl<'a, E> Debug for StrDeserializer<'a, E>

Source

impl<'a, I, A> Debug for aidoku::alloc::collections::vec_deque::Splice<'a, I, A>
where I: Debug + Iterator + 'a, A: Debug + Allocator + 'a, <I as Iterator>::Item: Debug,

1.21.0 · Source

impl<'a, I, A> Debug for aidoku::alloc::vec::Splice<'a, I, A>
where I: Debug + Iterator + 'a, A: Debug + Allocator + 'a, <I as Iterator>::Item: Debug,



impl<'a, I, A> Debug for Splice<'a, I, A>
where I: Debug + Iterator + 'a, A: Debug + Allocator + 'a, <I as Iterator>::Item: Debug,

Source

impl<'a, I> Debug for ByRefSized<'a, I>
where I: Debug,

1.5.0 · Source

impl<'a, P> Debug for MatchIndices<'a, P>
where P: Pattern, <P as Pattern>::Searcher<'a>: Debug,

1.2.0 · Source

impl<'a, P> Debug for Matches<'a, P>
where P: Pattern, <P as Pattern>::Searcher<'a>: Debug,

1.5.0 · Source

impl<'a, P> Debug for RMatchIndices<'a, P>
where P: Pattern, <P as Pattern>::Searcher<'a>: Debug,

1.2.0 · Source

impl<'a, P> Debug for RMatches<'a, P>
where P: Pattern, <P as Pattern>::Searcher<'a>: Debug,

1.0.0 · Source

impl<'a, P> Debug for aidoku::alloc::str::RSplit<'a, P>
where P: Pattern, <P as Pattern>::Searcher<'a>: Debug,

1.0.0 · Source

impl<'a, P> Debug for aidoku::alloc::str::RSplitN<'a, P>
where P: Pattern, <P as Pattern>::Searcher<'a>: Debug,

1.0.0 · Source

impl<'a, P> Debug for RSplitTerminator<'a, P>
where P: Pattern, <P as Pattern>::Searcher<'a>: Debug,

1.0.0 · Source

impl<'a, P> Debug for aidoku::alloc::str::Split<'a, P>
where P: Pattern, <P as Pattern>::Searcher<'a>: Debug,

1.51.0 · Source

impl<'a, P> Debug for aidoku::alloc::str::SplitInclusive<'a, P>
where P: Pattern, <P as Pattern>::Searcher<'a>: Debug,

1.0.0 · Source

impl<'a, P> Debug for aidoku::alloc::str::SplitN<'a, P>
where P: Pattern, <P as Pattern>::Searcher<'a>: Debug,

1.0.0 · Source

impl<'a, P> Debug for SplitTerminator<'a, P>
where P: Pattern, <P as Pattern>::Searcher<'a>: Debug,



impl<'a, R, G, T> Debug for MappedReentrantMutexGuard<'a, R, G, T>
where R: RawMutex + 'a, G: GetThreadId + 'a, T: Debug + 'a + ?Sized,



impl<'a, R, G, T> Debug for ReentrantMutexGuard<'a, R, G, T>
where R: RawMutex + 'a, G: GetThreadId + 'a, T: Debug + 'a + ?Sized,



impl<'a, R, T> Debug for MappedMutexGuard<'a, R, T>
where R: RawMutex + 'a, T: Debug + 'a + ?Sized,



impl<'a, R, T> Debug for MappedRwLockReadGuard<'a, R, T>
where R: RawRwLock + 'a, T: Debug + 'a + ?Sized,



impl<'a, R, T> Debug for MappedRwLockWriteGuard<'a, R, T>
where R: RawRwLock + 'a, T: Debug + 'a + ?Sized,



impl<'a, R, T> Debug for MutexGuard<'a, R, T>
where R: RawMutex + 'a, T: Debug + 'a + ?Sized,



impl<'a, R, T> Debug for RwLockReadGuard<'a, R, T>
where R: RawRwLock + 'a, T: Debug + 'a + ?Sized,



impl<'a, R, T> Debug for RwLockUpgradableReadGuard<'a, R, T>
where R: RawRwLockUpgrade + 'a, T: Debug + 'a + ?Sized,



impl<'a, R, T> Debug for RwLockWriteGuard<'a, R, T>
where R: RawRwLock + 'a, T: Debug + 'a + ?Sized,

1.6.0 · Source

impl<'a, T, A> Debug for aidoku::alloc::collections::binary_heap::Drain<'a, T, A>
where T: Debug + 'a, A: Debug + Allocator,

Source

impl<'a, T, A> Debug for DrainSorted<'a, T, A>
where T: Debug + Ord, A: Debug + Allocator,

1.77.0 · Source

impl<'a, T, P> Debug for ChunkBy<'a, T, P>
where T: 'a + Debug,

1.77.0 · Source

impl<'a, T, P> Debug for ChunkByMut<'a, T, P>
where T: 'a + Debug,

1.94.0 · Source

impl<'a, T, const N: usize> Debug for ArrayWindows<'a, T, N>
where T: Debug + 'a,

1.0.0 · Source

impl<'a, T> Debug for Chunks<'a, T>
where T: Debug + 'a,

1.31.0 · Source

impl<'a, T> Debug for ChunksExact<'a, T>
where T: Debug + 'a,

1.31.0 · Source

impl<'a, T> Debug for ChunksExactMut<'a, T>
where T: Debug + 'a,

1.0.0 · Source

impl<'a, T> Debug for ChunksMut<'a, T>
where T: Debug + 'a,

1.0.0 · Source

impl<'a, T> Debug for core::result::Iter<'a, T>
where T: Debug + 'a,

Source

impl<'a, T> Debug for std::sync::mpmc::Iter<'a, T>
where T: Debug + 'a,

1.0.0 · Source

impl<'a, T> Debug for std::sync::mpsc::Iter<'a, T>
where T: Debug + 'a,

1.0.0 · Source

impl<'a, T> Debug for core::result::IterMut<'a, T>
where T: Debug + 'a,



impl<'a, T> Debug for MutexGuard<'a, T>
where T: Debug + ?Sized,

1.31.0 · Source

impl<'a, T> Debug for RChunks<'a, T>
where T: Debug + 'a,

1.31.0 · Source

impl<'a, T> Debug for RChunksExact<'a, T>
where T: Debug + 'a,

1.31.0 · Source

impl<'a, T> Debug for RChunksExactMut<'a, T>
where T: Debug + 'a,

1.31.0 · Source

impl<'a, T> Debug for RChunksMut<'a, T>
where T: Debug + 'a,

1.17.0 · Source

impl<'a, T> Debug for aidoku::alloc::collections::btree_set::Range<'a, T>
where T: Debug + 'a,



impl<'a, T> Debug for SpinMutexGuard<'a, T>
where T: Debug + ?Sized,

Source

impl<'a, T> Debug for std::sync::mpmc::TryIter<'a, T>
where T: Debug + 'a,

1.15.0 · Source

impl<'a, T> Debug for std::sync::mpsc::TryIter<'a, T>
where T: Debug + 'a,

1.0.0 · Source

impl<'a, T> Debug for Windows<'a, T>
where T: Debug + 'a,

Source

impl<'a, const N: usize> Debug for CharArraySearcher<'a, N>

1.28.0 · Source

impl<'a> Debug for Ancestors<'a>

Source

impl<'a> Debug for core::ffi::c_str::Bytes<'a>

1.0.0 · Source

impl<'a> Debug for aidoku::alloc::str::Bytes<'a>

1.0.0 · Source

impl<'a> Debug for CharIndices<'a>

Source

impl<'a> Debug for CharSearcher<'a>



impl<'a> Debug for CobsDecoder<'a>



impl<'a> Debug for CobsEncoder<'a>

1.57.0 · Source

impl<'a> Debug for CommandArgs<'a>

1.57.0 · Source

impl<'a> Debug for CommandEnvs<'a>

1.0.0 · Source

impl<'a> Debug for Component<'a>

Source

impl<'a> Debug for ContextBuilder<'a>

1.60.0 · Source

impl<'a> Debug for EscapeAscii<'a>

1.34.0 · Source

impl<'a> Debug for aidoku::alloc::str::EscapeDebug<'a>

1.34.0 · Source

impl<'a> Debug for aidoku::alloc::str::EscapeDefault<'a>

1.34.0 · Source

impl<'a> Debug for aidoku::alloc::str::EscapeUnicode<'a>

1.0.0 · Source

impl<'a> Debug for std::net::tcp::Incoming<'a>

1.10.0 · Source

impl<'a> Debug for std::os::unix::net::listener::Incoming<'a>

1.36.0 · Source

impl<'a> Debug for IoSlice<'a>

1.36.0 · Source

impl<'a> Debug for IoSliceMut<'a>

1.0.0 · Source

impl<'a> Debug for aidoku::alloc::str::Lines<'a>

1.0.0 · Source

impl<'a> Debug for LinesAny<'a>

1.81.0 · Source

impl<'a> Debug for PanicHookInfo<'a>

1.10.0 · Source

impl<'a> Debug for PanicInfo<'a>

1.0.0 · Source

impl<'a> Debug for Prefix<'a>

1.0.0 · Source

impl<'a> Debug for PrefixComponent<'a>

Source

impl<'a> Debug for core::error::Request<'a>

Source

impl<'a> Debug for SocketAncillary<'a>

Source

impl<'a> Debug for Source<'a>

1.34.0 · Source

impl<'a> Debug for SplitAsciiWhitespace<'a>

1.1.0 · Source

impl<'a> Debug for SplitWhitespace<'a>

Source

impl<'a> Debug for Unexpected<'a>

1.79.0 · Source

impl<'a> Debug for Utf8Chunk<'a>

Source

impl<'a> Debug for Utf8Pattern<'a>

Source

impl<'de, E> Debug for BorrowedBytesDeserializer<'de, E>

Source

impl<'de, E> Debug for BorrowedStrDeserializer<'de, E>

Source

impl<'de, I, E> Debug for MapDeserializer<'de, I, E>
where I: Iterator + Debug, <I as Iterator>::Item: Pair, <<I as Iterator>::Item as Pair>::Second: Debug,



impl<'rwlock, T, R> Debug for RwLockUpgradableGuard<'rwlock, T, R>
where T: Debug + ?Sized,



impl<'rwlock, T, R> Debug for RwLockWriteGuard<'rwlock, T, R>
where T: Debug + ?Sized,



impl<'rwlock, T> Debug for RwLockReadGuard<'rwlock, T>
where T: Debug + ?Sized,

1.63.0 · Source

impl<'scope, T> Debug for ScopedJoinHandle<'scope, T>

1.0.0 · Source

impl<A, B> Debug for core::iter::adapters::chain::Chain<A, B>
where A: Debug, B: Debug,

1.0.0 · Source

impl<A, B> Debug for Zip<A, B>
where A: Debug, B: Debug,

Source

impl<A> Debug for EnumAccessDeserializer<A>
where A: Debug,

1.0.0 · Source

impl<A> Debug for core::option::IntoIter<A>
where A: Debug,

Source

impl<A> Debug for MapAccessDeserializer<A>
where A: Debug,

Source

impl<A> Debug for OptionFlatten<A>
where A: Debug,

1.96.0 · Source

impl<A> Debug for RangeFromIter<A>
where A: Debug,

1.95.0 · Source

impl<A> Debug for RangeInclusiveIter<A>
where A: Debug,

1.96.0 · Source

impl<A> Debug for RangeIter<A>
where A: Debug,

1.0.0 · Source

impl<A> Debug for core::iter::sources::repeat::Repeat<A>
where A: Debug,

1.82.0 · Source

impl<A> Debug for RepeatN<A>
where A: Debug,

Source

impl<A> Debug for SeqAccessDeserializer<A>
where A: Debug,

1.55.0 · Source

impl<B, C> Debug for ControlFlow<B, C>
where B: Debug, C: Debug,

1.0.0 · Source

impl<B> Debug for Cow<'_, B>
where B: Debug + ToOwned + ?Sized, <B as ToOwned>::Owned: Debug,

1.0.0 · Source

impl<B> Debug for std::io::Lines<B>
where B: Debug,

1.0.0 · Source

impl<B> Debug for std::io::Split<B>
where B: Debug,

Source

impl<Dyn> Debug for DynMetadata<Dyn>
where Dyn: ?Sized,

Source

impl<E> Debug for BoolDeserializer<E>

Source

impl<E> Debug for CharDeserializer<E>

Source

impl<E> Debug for F32Deserializer<E>

Source

impl<E> Debug for F64Deserializer<E>

Source

impl<E> Debug for I8Deserializer<E>

Source

impl<E> Debug for I16Deserializer<E>

Source

impl<E> Debug for I32Deserializer<E>

Source

impl<E> Debug for I64Deserializer<E>

Source

impl<E> Debug for I128Deserializer<E>

Source

impl<E> Debug for IsizeDeserializer<E>

Source

impl<E> Debug for Report<E>
where Report<E>: Display,

Source

impl<E> Debug for StringDeserializer<E>

Available on crate features alloc or std only.
Source

impl<E> Debug for U8Deserializer<E>

Source

impl<E> Debug for U16Deserializer<E>

Source

impl<E> Debug for U32Deserializer<E>

Source

impl<E> Debug for U64Deserializer<E>

Source

impl<E> Debug for U128Deserializer<E>

Source

impl<E> Debug for UnitDeserializer<E>

Source

impl<E> Debug for UsizeDeserializer<E>

Source

impl<F> Debug for CharPredicateSearcher<'_, F>
where F: FnMut(char) -> bool,

1.4.0 · Source

impl<F> Debug for F
where F: FnPtr,

1.34.0 · Source

impl<F> Debug for core::iter::sources::from_fn::FromFn<F>

1.93.0 · Source

impl<F> Debug for aidoku::alloc::fmt::FromFn<F>
where F: Fn(&mut Formatter<'_>) -> Result<(), Error>,

1.68.0 · Source

impl<F> Debug for OnceWith<F>

1.64.0 · Source

impl<F> Debug for PollFn<F>

1.68.0 · Source

impl<F> Debug for RepeatWith<F>

Source

impl<G> Debug for FromCoroutine<G>

1.9.0 · Source

impl<H> Debug for core::hash::BuildHasherDefault<H>



impl<H> Debug for BuildHasherDefault<H>
where H: Default + Hasher,

Source

impl<I, E> Debug for SeqDeserializer<I, E>
where I: Debug,

Source

impl<I, F, const N: usize> Debug for MapWindows<I, F, N>
where I: Iterator + Debug,

1.9.0 · Source

impl<I, F> Debug for FilterMap<I, F>
where I: Debug,

1.9.0 · Source

impl<I, F> Debug for Inspect<I, F>
where I: Debug,

1.9.0 · Source

impl<I, F> Debug for Map<I, F>
where I: Debug,

Source

impl<I, G> Debug for IntersperseWith<I, G>
where I: Iterator + Debug, <I as Iterator>::Item: Debug, G: Debug,

1.9.0 · Source

impl<I, P> Debug for core::iter::adapters::filter::Filter<I, P>
where I: Debug,

1.57.0 · Source

impl<I, P> Debug for MapWhile<I, P>
where I: Debug,

1.9.0 · Source

impl<I, P> Debug for SkipWhile<I, P>
where I: Debug,

1.9.0 · Source

impl<I, P> Debug for TakeWhile<I, P>
where I: Debug,

1.9.0 · Source

impl<I, St, F> Debug for Scan<I, St, F>
where I: Debug, St: Debug,

1.9.0 · Source

impl<I, U, F> Debug for FlatMap<I, U, F>
where I: Debug, U: IntoIterator, <U as IntoIterator>::IntoIter: Debug,

1.29.0 · Source

impl<I, U> Debug for Flatten<I>
where I: Debug + Iterator, <I as Iterator>::Item: IntoIterator<IntoIter = U, Item = <U as Iterator>::Item>, U: Debug + Iterator,

Source

impl<I, const N: usize> Debug for ArrayChunks<I, N>
where I: Debug + Iterator, <I as Iterator>::Item: Debug,

1.1.0 · Source

impl<I> Debug for Cloned<I>
where I: Debug,

1.36.0 · Source

impl<I> Debug for Copied<I>
where I: Debug,

1.0.0 · Source

impl<I> Debug for Cycle<I>
where I: Debug,

1.9.0 · Source

impl<I> Debug for DecodeUtf16<I>
where I: Debug + Iterator<Item = u16>,

1.0.0 · Source

impl<I> Debug for Enumerate<I>
where I: Debug,

Source

impl<I> Debug for FromIter<I>
where I: Debug,

1.0.0 · Source

impl<I> Debug for Fuse<I>
where I: Debug,

Source

impl<I> Debug for Intersperse<I>
where I: Debug + Iterator, <I as Iterator>::Item: Clone + Debug,

1.0.0 · Source

impl<I> Debug for Peekable<I>
where I: Debug + Iterator, <I as Iterator>::Item: Debug,

1.0.0 · Source

impl<I> Debug for Skip<I>
where I: Debug,

1.28.0 · Source

impl<I> Debug for StepBy<I>
where I: Debug,

1.0.0 · Source

impl<I> Debug for core::iter::adapters::take::Take<I>
where I: Debug,

Source

impl<Idx> Debug for Clamp<Idx>
where Idx: Debug,

1.0.0 · Source

impl<Idx> Debug for core::ops::range::Range<Idx>
where Idx: Debug,

1.96.0 · Source

impl<Idx> Debug for core::range::Range<Idx>
where Idx: Debug,

1.0.0 · Source

impl<Idx> Debug for core::ops::range::RangeFrom<Idx>
where Idx: Debug,

1.96.0 · Source

impl<Idx> Debug for core::range::RangeFrom<Idx>
where Idx: Debug,

1.26.0 · Source

impl<Idx> Debug for core::ops::range::RangeInclusive<Idx>
where Idx: Debug,

1.95.0 · Source

impl<Idx> Debug for core::range::RangeInclusive<Idx>
where Idx: Debug,

1.0.0 · Source

impl<Idx> Debug for RangeTo<Idx>
where Idx: Debug,

1.26.0 · Source

impl<Idx> Debug for core::ops::range::RangeToInclusive<Idx>
where Idx: Debug,

1.96.0 · Source

impl<Idx> Debug for core::range::RangeToInclusive<Idx>
where Idx: Debug,

Source

impl<K, A> Debug for aidoku::alloc::collections::btree_set::CursorMut<'_, K, A>
where K: Debug,

Source

impl<K, A> Debug for aidoku::alloc::collections::btree_set::CursorMutKey<'_, K, A>
where K: Debug,

1.16.0 · Source

impl<K, A> Debug for std::collections::hash::set::Drain<'_, K, A>
where K: Debug, A: Allocator,



impl<K, A> Debug for Drain<'_, K, A>
where K: Debug, A: Allocator,

1.16.0 · Source

impl<K, A> Debug for std::collections::hash::set::IntoIter<K, A>
where K: Debug, A: Allocator,



impl<K, A> Debug for IntoIter<K, A>
where K: Debug, A: Allocator,

1.88.0 · Source

impl<K, F, A> Debug for std::collections::hash::set::ExtractIf<'_, K, F, A>
where A: Allocator, K: Debug,



impl<K, Q, V, S, A> Debug for EntryRef<'_, '_, K, Q, V, S, A>
where K: Debug + Borrow<Q>, Q: Debug + ?Sized, V: Debug, A: Allocator,



impl<K, Q, V, S, A> Debug for VacantEntryRef<'_, '_, K, Q, V, S, A>
where K: Borrow<Q>, Q: Debug + ?Sized, A: Allocator,

1.0.0 · Source

impl<K, V, A> Debug for BTreeMap<K, V, A>
where K: Debug, V: Debug, A: Allocator + Clone,

Source

impl<K, V, A> Debug for aidoku::alloc::collections::btree_map::CursorMut<'_, K, V, A>
where K: Debug, V: Debug,

Source

impl<K, V, A> Debug for aidoku::alloc::collections::btree_map::CursorMutKey<'_, K, V, A>
where K: Debug, V: Debug,

1.16.0 · Source

impl<K, V, A> Debug for std::collections::hash::map::Drain<'_, K, V, A>
where A: Allocator, K: Debug, V: Debug,



impl<K, V, A> Debug for Drain<'_, K, V, A>
where K: Debug, V: Debug, A: Allocator,

1.12.0 · Source

impl<K, V, A> Debug for aidoku::alloc::collections::btree_map::Entry<'_, K, V, A>
where K: Debug + Ord, V: Debug, A: Allocator + Clone,

1.17.0 · Source

impl<K, V, A> Debug for aidoku::alloc::collections::btree_map::IntoIter<K, V, A>
where K: Debug, V: Debug, A: Allocator + Clone,

1.16.0 · Source

impl<K, V, A> Debug for std::collections::hash::map::IntoIter<K, V, A>
where K: Debug, V: Debug, A: Allocator,



impl<K, V, A> Debug for IntoIter<K, V, A>
where K: Debug, V: Debug, A: Allocator,

1.54.0 · Source

impl<K, V, A> Debug for aidoku::alloc::collections::btree_map::IntoKeys<K, V, A>
where K: Debug, A: Allocator + Clone,

1.54.0 · Source

impl<K, V, A> Debug for std::collections::hash::map::IntoKeys<K, V, A>
where K: Debug, A: Allocator,



impl<K, V, A> Debug for IntoKeys<K, V, A>
where K: Debug, V: Debug, A: Allocator,

1.54.0 · Source

impl<K, V, A> Debug for aidoku::alloc::collections::btree_map::IntoValues<K, V, A>
where V: Debug, A: Allocator + Clone,

1.54.0 · Source

impl<K, V, A> Debug for std::collections::hash::map::IntoValues<K, V, A>
where V: Debug, A: Allocator,



impl<K, V, A> Debug for IntoValues<K, V, A>
where V: Debug, A: Allocator,

1.12.0 · Source

impl<K, V, A> Debug for aidoku::alloc::collections::btree_map::OccupiedEntry<'_, K, V, A>
where K: Debug + Ord, V: Debug, A: Allocator + Clone,

1.12.0 · Source

impl<K, V, A> Debug for std::collections::hash::map::OccupiedEntry<'_, K, V, A>
where K: Debug, V: Debug, A: Allocator,

Source

impl<K, V, A> Debug for aidoku::alloc::collections::btree_map::OccupiedError<'_, K, V, A>
where K: Debug + Ord, V: Debug, A: Allocator + Clone,

Source

impl<K, V, A> Debug for std::collections::hash::map::OccupiedError<'_, K, V, A>
where K: Debug, V: Debug, A: Allocator,

1.12.0 · Source

impl<K, V, A> Debug for aidoku::alloc::collections::btree_map::VacantEntry<'_, K, V, A>
where K: Debug + Ord, A: Allocator + Clone,

1.12.0 · Source

impl<K, V, A> Debug for std::collections::hash::map::VacantEntry<'_, K, V, A>
where K: Debug, A: Allocator,

1.88.0 · Source

impl<K, V, F, A> Debug for std::collections::hash::map::ExtractIf<'_, K, V, F, A>
where A: Allocator, K: Debug, V: Debug,

1.91.0 · Source

impl<K, V, R, F, A> Debug for aidoku::alloc::collections::btree_map::ExtractIf<'_, K, V, R, F, A>
where K: Debug, V: Debug, A: Allocator + Clone,



impl<K, V, S, A> Debug for Entry<'_, K, V, S, A>
where K: Debug, V: Debug, A: Allocator,

1.0.0 · Source

impl<K, V, S, A> Debug for std::collections::hash::map::HashMap<K, V, S, A>
where K: Debug, V: Debug, A: Allocator,



impl<K, V, S, A> Debug for aidoku::HashMap<K, V, S, A>
where K: Debug, V: Debug, A: Allocator,



impl<K, V, S, A> Debug for OccupiedEntry<'_, K, V, S, A>
where K: Debug, V: Debug, A: Allocator,



impl<K, V, S, A> Debug for OccupiedError<'_, K, V, S, A>
where K: Debug, V: Debug, A: Allocator,



impl<K, V, S, A> Debug for RawEntryBuilder<'_, K, V, S, A>
where A: Allocator,



impl<K, V, S, A> Debug for RawEntryBuilderMut<'_, K, V, S, A>
where A: Allocator,



impl<K, V, S, A> Debug for RawEntryMut<'_, K, V, S, A>
where K: Debug, V: Debug, A: Allocator,



impl<K, V, S, A> Debug for RawOccupiedEntryMut<'_, K, V, S, A>
where K: Debug, V: Debug, A: Allocator,



impl<K, V, S, A> Debug for RawVacantEntryMut<'_, K, V, S, A>
where A: Allocator,



impl<K, V, S, A> Debug for VacantEntry<'_, K, V, S, A>
where K: Debug, A: Allocator,



impl<K, V, S, const N: usize> Debug for IndexMap<K, V, S, N>
where K: Eq + Hash + Debug, V: Debug, S: BuildHasher,



impl<K, V, const N: usize> Debug for LinearMap<K, V, N>
where K: Eq + Debug, V: Debug,

Source

impl<K, V> Debug for aidoku::alloc::collections::btree_map::Cursor<'_, K, V>
where K: Debug, V: Debug,

1.12.0 · Source

impl<K, V> Debug for std::collections::hash::map::Entry<'_, K, V>
where K: Debug, V: Debug,

1.17.0 · Source

impl<K, V> Debug for aidoku::alloc::collections::btree_map::Iter<'_, K, V>
where K: Debug, V: Debug,

1.16.0 · Source

impl<K, V> Debug for std::collections::hash::map::Iter<'_, K, V>
where K: Debug, V: Debug,



impl<K, V> Debug for Iter<'_, K, V>
where K: Debug, V: Debug,

1.17.0 · Source

impl<K, V> Debug for aidoku::alloc::collections::btree_map::IterMut<'_, K, V>
where K: Debug, V: Debug,

1.16.0 · Source

impl<K, V> Debug for std::collections::hash::map::IterMut<'_, K, V>
where K: Debug, V: Debug,



impl<K, V> Debug for IterMut<'_, K, V>
where K: Debug, V: Debug,

1.17.0 · Source

impl<K, V> Debug for aidoku::alloc::collections::btree_map::Keys<'_, K, V>
where K: Debug,

1.16.0 · Source

impl<K, V> Debug for std::collections::hash::map::Keys<'_, K, V>
where K: Debug,



impl<K, V> Debug for Keys<'_, K, V>
where K: Debug,

1.17.0 · Source

impl<K, V> Debug for aidoku::alloc::collections::btree_map::Range<'_, K, V>
where K: Debug, V: Debug,

1.17.0 · Source

impl<K, V> Debug for RangeMut<'_, K, V>
where K: Debug, V: Debug,

1.17.0 · Source

impl<K, V> Debug for aidoku::alloc::collections::btree_map::Values<'_, K, V>
where V: Debug,

1.16.0 · Source

impl<K, V> Debug for std::collections::hash::map::Values<'_, K, V>
where V: Debug,



impl<K, V> Debug for Values<'_, K, V>
where V: Debug,

1.10.0 · Source

impl<K, V> Debug for aidoku::alloc::collections::btree_map::ValuesMut<'_, K, V>
where V: Debug,

1.16.0 · Source

impl<K, V> Debug for std::collections::hash::map::ValuesMut<'_, K, V>
where V: Debug,



impl<K, V> Debug for ValuesMut<'_, K, V>
where V: Debug,

Source

impl<K> Debug for aidoku::alloc::collections::btree_set::Cursor<'_, K>
where K: Debug,

1.16.0 · Source

impl<K> Debug for std::collections::hash::set::Iter<'_, K>
where K: Debug,



impl<K> Debug for Iter<'_, K>
where K: Debug,



impl<O> Debug for Talc<O>
where O: OomHandler,



impl<P> Debug for Arc<P>
where P: Pool, <P as Pool>::Data: Debug,



impl<P> Debug for Box<P>
where P: Pool, <P as Pool>::Data: Debug,

Source

impl<P> Debug for MaybeDangling<P>
where P: Debug + ?Sized,

1.33.0 · Source

impl<Ptr> Debug for Pin<Ptr>
where Ptr: Debug,



impl<R, G, T> Debug for ReentrantMutex<R, G, T>
where R: RawMutex, G: GetThreadId, T: Debug + ?Sized,



impl<R, O> Debug for Talck<R, O>
where R: Debug + RawMutex, O: Debug + OomHandler,



impl<R, T> Debug for Mutex<R, T>
where R: RawMutex, T: Debug + ?Sized,



impl<R, T> Debug for RwLock<R, T>
where R: RawRwLock, T: Debug + ?Sized,

1.0.0 · Source

impl<R> Debug for BufReader<R>
where R: Debug + ?Sized,

1.0.0 · Source

impl<R> Debug for std::io::Bytes<R>
where R: Debug,



impl<T, A> Debug for AbsentEntry<'_, T, A>
where T: Debug, A: Allocator,

1.0.0 · Source

impl<T, A> Debug for aidoku::alloc::sync::Arc<T, A>
where T: Debug + ?Sized, A: Allocator,

1.0.0 · Source

impl<T, A> Debug for BTreeSet<T, A>
where T: Debug, A: Allocator + Clone,

1.4.0 · Source

impl<T, A> Debug for aidoku::alloc::collections::binary_heap::BinaryHeap<T, A>
where T: Debug, A: Allocator,

1.0.0 · Source

impl<T, A> Debug for aidoku::alloc::Box<T, A>
where T: Debug + ?Sized, A: Allocator,



impl<T, A> Debug for Box<T, A>
where T: Debug + ?Sized, A: Allocator,

Source

impl<T, A> Debug for aidoku::alloc::collections::linked_list::Cursor<'_, T, A>
where T: Debug, A: Allocator,

Source

impl<T, A> Debug for aidoku::alloc::collections::linked_list::CursorMut<'_, T, A>
where T: Debug, A: Allocator,

1.17.0 · Source

impl<T, A> Debug for aidoku::alloc::collections::btree_set::Difference<'_, T, A>
where T: Debug, A: Allocator + Clone,

1.17.0 · Source

impl<T, A> Debug for aidoku::alloc::collections::vec_deque::Drain<'_, T, A>
where T: Debug, A: Allocator,

1.17.0 · Source

impl<T, A> Debug for aidoku::alloc::vec::Drain<'_, T, A>
where T: Debug, A: Allocator,



impl<T, A> Debug for Drain<'_, T, A>
where T: Debug, A: Allocator,



impl<T, A> Debug for Drain<'_, T, A>
where T: Debug, A: Allocator,

Source

impl<T, A> Debug for aidoku::alloc::collections::btree_set::Entry<'_, T, A>
where T: Debug + Ord, A: Allocator + Clone,



impl<T, A> Debug for Entry<'_, T, A>
where T: Debug, A: Allocator,



impl<T, A> Debug for HashTable<T, A>
where T: Debug, A: Allocator,

1.17.0 · Source

impl<T, A> Debug for aidoku::alloc::collections::btree_set::Intersection<'_, T, A>
where T: Debug, A: Allocator + Clone,

1.17.0 · Source

impl<T, A> Debug for aidoku::alloc::collections::binary_heap::IntoIter<T, A>
where T: Debug, A: Allocator,

1.17.0 · Source

impl<T, A> Debug for aidoku::alloc::collections::linked_list::IntoIter<T, A>
where T: Debug, A: Allocator,

1.17.0 · Source

impl<T, A> Debug for aidoku::alloc::collections::vec_deque::IntoIter<T, A>
where T: Debug, A: Allocator,

1.13.0 · Source

impl<T, A> Debug for aidoku::alloc::vec::IntoIter<T, A>
where T: Debug, A: Allocator,



impl<T, A> Debug for IntoIter<T, A>
where T: Debug, A: Allocator,



impl<T, A> Debug for IntoIter<T, A>
where T: Debug, A: Allocator,

1.0.0 · Source

impl<T, A> Debug for aidoku::alloc::collections::btree_set::IntoIter<T, A>
where T: Debug, A: Debug + Allocator + Clone,

Source

impl<T, A> Debug for IntoIterSorted<T, A>
where T: Debug, A: Debug + Allocator,

1.0.0 · Source

impl<T, A> Debug for LinkedList<T, A>
where T: Debug, A: Allocator,

Source

impl<T, A> Debug for aidoku::alloc::collections::btree_set::OccupiedEntry<'_, T, A>
where T: Debug + Ord, A: Allocator + Clone,



impl<T, A> Debug for OccupiedEntry<'_, T, A>
where T: Debug, A: Allocator,

Source

impl<T, A> Debug for aidoku::alloc::vec::PeekMut<'_, T, A>
where T: Debug, A: Allocator,

1.17.0 · Source

impl<T, A> Debug for aidoku::alloc::collections::binary_heap::PeekMut<'_, T, A>
where T: Ord + Debug, A: Allocator,

1.0.0 · Source

impl<T, A> Debug for Rc<T, A>
where T: Debug + ?Sized, A: Allocator,

Source

impl<T, A> Debug for UniqueArc<T, A>
where T: Debug + ?Sized, A: Allocator,

Source

impl<T, A> Debug for UniqueRc<T, A>
where T: Debug + ?Sized, A: Allocator,

Source

impl<T, A> Debug for aidoku::alloc::collections::btree_set::VacantEntry<'_, T, A>
where T: Debug + Ord, A: Allocator + Clone,



impl<T, A> Debug for VacantEntry<'_, T, A>
where T: Debug, A: Allocator,

1.0.0 · Source

impl<T, A> Debug for aidoku::alloc::Vec<T, A>
where T: Debug, A: Allocator,



impl<T, A> Debug for Vec<T, A>
where T: Debug, A: Allocator,

1.0.0 · Source

impl<T, A> Debug for VecDeque<T, A>
where T: Debug, A: Allocator,

1.4.0 · Source

impl<T, A> Debug for aidoku::alloc::rc::Weak<T, A>
where A: Allocator, T: ?Sized,

1.4.0 · Source

impl<T, A> Debug for aidoku::alloc::sync::Weak<T, A>
where A: Allocator, T: ?Sized,

1.0.0 · Source

impl<T, E> Debug for Result<T, E>
where T: Debug, E: Debug,

1.87.0 · Source

impl<T, F, A> Debug for aidoku::alloc::collections::linked_list::ExtractIf<'_, T, F, A>
where T: Debug, A: Allocator,

Source

impl<T, F, A> Debug for aidoku::alloc::collections::vec_deque::ExtractIf<'_, T, F, A>
where T: Debug, A: Allocator,

1.87.0 · Source

impl<T, F, A> Debug for aidoku::alloc::vec::ExtractIf<'_, T, F, A>
where T: Debug, A: Allocator,



impl<T, F, R> Debug for Lazy<T, F, R>
where T: Debug,

Source

impl<T, F, S> Debug for ScopeGuard<T, F, S>
where T: Debug, F: FnOnce(T), S: Strategy,

Source

impl<T, F> Debug for DropGuard<T, F>
where T: Debug, F: FnOnce(T),

1.80.0 · Source

impl<T, F> Debug for LazyCell<T, F>
where T: Debug,

1.80.0 · Source

impl<T, F> Debug for LazyLock<T, F>
where T: Debug,

1.34.0 · Source

impl<T, F> Debug for Successors<T, F>
where T: Debug,



impl<T, Idx, K, const N: usize> Debug for SortedLinkedList<T, Idx, K, N>
where T: Ord + Debug, Idx: SortedLinkedListIndex, K: Kind,



impl<T, K, const N: usize> Debug for BinaryHeap<T, K, N>
where K: Kind, T: Ord + Debug,

1.27.0 · Source

impl<T, P> Debug for aidoku::alloc::slice::RSplit<'_, T, P>
where T: Debug, P: FnMut(&T) -> bool,

1.27.0 · Source

impl<T, P> Debug for RSplitMut<'_, T, P>
where T: Debug, P: FnMut(&T) -> bool,

1.9.0 · Source

impl<T, P> Debug for aidoku::alloc::slice::RSplitN<'_, T, P>
where T: Debug, P: FnMut(&T) -> bool,

1.9.0 · Source

impl<T, P> Debug for RSplitNMut<'_, T, P>
where T: Debug, P: FnMut(&T) -> bool,

1.9.0 · Source

impl<T, P> Debug for aidoku::alloc::slice::Split<'_, T, P>
where T: Debug, P: FnMut(&T) -> bool,

1.51.0 · Source

impl<T, P> Debug for aidoku::alloc::slice::SplitInclusive<'_, T, P>
where T: Debug, P: FnMut(&T) -> bool,

1.51.0 · Source

impl<T, P> Debug for SplitInclusiveMut<'_, T, P>
where T: Debug, P: FnMut(&T) -> bool,

1.9.0 · Source

impl<T, P> Debug for SplitMut<'_, T, P>
where T: Debug, P: FnMut(&T) -> bool,

1.9.0 · Source

impl<T, P> Debug for aidoku::alloc::slice::SplitN<'_, T, P>
where T: Debug, P: FnMut(&T) -> bool,

1.9.0 · Source

impl<T, P> Debug for SplitNMut<'_, T, P>
where T: Debug, P: FnMut(&T) -> bool,

1.91.0 · Source

impl<T, R, F, A> Debug for aidoku::alloc::collections::btree_set::ExtractIf<'_, T, R, F, A>
where T: Debug, A: Allocator + Clone,



impl<T, R> Debug for Mutex<T, R>
where T: Debug + ?Sized,



impl<T, R> Debug for Once<T, R>
where T: Debug,



impl<T, R> Debug for RwLock<T, R>
where T: Debug + ?Sized,



impl<T, R> Debug for SpinMutex<T, R>
where T: Debug + ?Sized,

1.16.0 · Source

impl<T, S, A> Debug for std::collections::hash::set::Difference<'_, T, S, A>
where T: Debug + Eq + Hash, S: BuildHasher, A: Allocator,



impl<T, S, A> Debug for Difference<'_, T, S, A>
where T: Debug + Eq + Hash, S: BuildHasher, A: Allocator,

Source

impl<T, S, A> Debug for std::collections::hash::set::Entry<'_, T, S, A>
where T: Debug, A: Allocator,



impl<T, S, A> Debug for Entry<'_, T, S, A>
where T: Debug, A: Allocator,

1.0.0 · Source

impl<T, S, A> Debug for std::collections::hash::set::HashSet<T, S, A>
where T: Debug, A: Allocator,



impl<T, S, A> Debug for HashSet<T, S, A>
where T: Debug, A: Allocator,

1.16.0 · Source

impl<T, S, A> Debug for std::collections::hash::set::Intersection<'_, T, S, A>
where T: Debug + Eq + Hash, S: BuildHasher, A: Allocator,



impl<T, S, A> Debug for Intersection<'_, T, S, A>
where T: Debug + Eq + Hash, S: BuildHasher, A: Allocator,

Source

impl<T, S, A> Debug for std::collections::hash::set::OccupiedEntry<'_, T, S, A>
where T: Debug, A: Allocator,



impl<T, S, A> Debug for OccupiedEntry<'_, T, S, A>
where T: Debug, A: Allocator,

1.16.0 · Source

impl<T, S, A> Debug for std::collections::hash::set::SymmetricDifference<'_, T, S, A>
where T: Debug + Eq + Hash, S: BuildHasher, A: Allocator,



impl<T, S, A> Debug for SymmetricDifference<'_, T, S, A>
where T: Debug + Eq + Hash, S: BuildHasher, A: Allocator,

1.16.0 · Source

impl<T, S, A> Debug for std::collections::hash::set::Union<'_, T, S, A>
where A: Allocator, T: Debug + Eq + Hash, S: BuildHasher,



impl<T, S, A> Debug for Union<'_, T, S, A>
where T: Debug + Eq + Hash, S: BuildHasher, A: Allocator,

Source

impl<T, S, A> Debug for std::collections::hash::set::VacantEntry<'_, T, S, A>
where T: Debug, A: Allocator,



impl<T, S, A> Debug for VacantEntry<'_, T, S, A>
where T: Debug, A: Allocator,



impl<T, S, const N: usize> Debug for IndexSet<T, S, N>
where T: Eq + Hash + Debug, S: BuildHasher,



impl<T, Src, Dst> Debug for RigidTransform3D<T, Src, Dst>
where T: Debug,



impl<T, Src, Dst> Debug for Rotation2D<T, Src, Dst>
where T: Debug,



impl<T, Src, Dst> Debug for Rotation3D<T, Src, Dst>
where T: Debug,



impl<T, Src, Dst> Debug for Scale<T, Src, Dst>
where T: Debug,



impl<T, Src, Dst> Debug for ScaleOffset2D<T, Src, Dst>
where T: Copy + Debug + PartialEq + One + Zero + ApproxEq<T>,



impl<T, Src, Dst> Debug for Transform2D<T, Src, Dst>
where T: Copy + Debug + PartialEq + One + Zero,



impl<T, Src, Dst> Debug for Transform3D<T, Src, Dst>
where T: Copy + Debug + PartialEq + One + Zero,



impl<T, Src, Dst> Debug for Translation2D<T, Src, Dst>
where T: Debug,



impl<T, Src, Dst> Debug for Translation3D<T, Src, Dst>
where T: Debug,



impl<T, U> Debug for Box2D<T, U>
where T: Debug,



impl<T, U> Debug for Box3D<T, U>
where T: Debug,

1.0.0 · Source

impl<T, U> Debug for aidoku::alloc::io::Chain<T, U>
where T: Debug, U: Debug,



impl<T, U> Debug for HomogeneousVector<T, U>
where T: Debug,



impl<T, U> Debug for Length<T, U>
where T: Debug,



impl<T, U> Debug for Point2D<T, U>
where T: Debug,



impl<T, U> Debug for Point3D<T, U>
where T: Debug,



impl<T, U> Debug for Rect<T, U>
where T: Debug,



impl<T, U> Debug for SideOffsets2D<T, U>
where T: Debug,



impl<T, U> Debug for Size2D<T, U>
where T: Debug,



impl<T, U> Debug for Size3D<T, U>
where T: Debug,



impl<T, U> Debug for Vector2D<T, U>
where T: Debug,



impl<T, U> Debug for Vector3D<T, U>
where T: Debug,



impl<T, const N: usize> Debug for Deque<T, N>
where T: Debug,



impl<T, const N: usize> Debug for HistoryBuffer<T, N>
where T: Debug,

1.40.0 · Source

impl<T, const N: usize> Debug for core::array::iter::IntoIter<T, N>
where T: Debug,

Source

impl<T, const N: usize> Debug for Mask<T, N>
where T: MaskElement + Debug,



impl<T, const N: usize> Debug for Queue<T, N>
where T: Debug,

Source

impl<T, const N: usize> Debug for Simd<T, N>
where T: SimdElement + Debug,



impl<T, const N: usize> Debug for Vec<T, N>
where T: Debug,

1.0.0 · Source

impl<T, const N: usize> Debug for [T; N]
where T: Debug,

Source

impl<T, const VARIANT: u32, const FIELD: u32> Debug for FieldRepresentingType<T, VARIANT, FIELD>
where T: ?Sized,

1.0.0 · Source

impl<T> Debug for &T
where T: Debug + ?Sized,

1.0.0 · Source

impl<T> Debug for &mut T
where T: Debug + ?Sized,

1.0.0 · Source

impl<T> Debug for (T₁, T₂, …, Tₙ)
where T: Debug,

This trait is implemented for tuples up to twelve items long.

1.0.0 · Source

impl<T> Debug for *const T
where T: ?Sized,

1.0.0 · Source

impl<T> Debug for *mut T
where T: ?Sized,



impl<T> Debug for Angle<T>
where T: Debug,

1.16.0 · Source

impl<T> Debug for AssertUnwindSafe<T>
where T: Debug,

1.3.0 · Source

impl<T> Debug for Atomic<*mut T>

Available on target_has_atomic_load_store=ptr only.
Source

impl<T> Debug for BorrowedBuf<'_, T>

Source

impl<T> Debug for BorrowedCursor<'_, T>

1.17.0 · Source

impl<T> Debug for Bound<T>
where T: Debug,



impl<T> Debug for Box<T>
where T: Debug,

1.0.0 · Source

impl<T> Debug for Cell<T>
where T: Copy + Debug,

1.0.0 · Source

impl<T> Debug for aidoku::alloc::io::Cursor<T>
where T: Debug,

1.21.0 · Source

impl<T> Debug for Discriminant<T>

1.9.0 · Source

impl<T> Debug for core::iter::sources::empty::Empty<T>

1.0.0 · Source

impl<T> Debug for core::result::IntoIter<T>
where T: Debug,

Source

impl<T> Debug for std::sync::mpmc::IntoIter<T>
where T: Debug,

1.1.0 · Source

impl<T> Debug for std::sync::mpsc::IntoIter<T>
where T: Debug,

1.9.0 · Source

impl<T> Debug for aidoku::alloc::slice::Iter<'_, T>
where T: Debug,

1.17.0 · Source

impl<T> Debug for aidoku::alloc::collections::binary_heap::Iter<'_, T>
where T: Debug,

1.17.0 · Source

impl<T> Debug for aidoku::alloc::collections::btree_set::Iter<'_, T>
where T: Debug,

1.17.0 · Source

impl<T> Debug for aidoku::alloc::collections::linked_list::Iter<'_, T>
where T: Debug,

1.17.0 · Source

impl<T> Debug for aidoku::alloc::collections::vec_deque::Iter<'_, T>
where T: Debug,



impl<T> Debug for Iter<'_, T>
where T: Debug,



impl<T> Debug for IterBuckets<'_, T>



impl<T> Debug for IterHash<'_, T>
where T: Debug,



impl<T> Debug for IterHashBuckets<'_, T>



impl<T> Debug for IterHashMut<'_, T>
where T: Debug,

1.9.0 · Source

impl<T> Debug for aidoku::alloc::slice::IterMut<'_, T>
where T: Debug,

1.17.0 · Source

impl<T> Debug for aidoku::alloc::collections::linked_list::IterMut<'_, T>
where T: Debug,

1.17.0 · Source

impl<T> Debug for aidoku::alloc::collections::vec_deque::IterMut<'_, T>
where T: Debug,



impl<T> Debug for IterMut<'_, T>
where T: Debug,

1.16.0 · Source

impl<T> Debug for JoinHandle<T>

1.16.0 · Source

impl<T> Debug for LocalKey<T>
where T: 'static,

1.20.0 · Source

impl<T> Debug for ManuallyDrop<T>
where T: Debug + ?Sized,

Source

impl<T> Debug for std::sync::nonpoison::mutex::MappedMutexGuard<'_, T>
where T: Debug + ?Sized,

Source

impl<T> Debug for std::sync::poison::mutex::MappedMutexGuard<'_, T>
where T: Debug + ?Sized,

Source

impl<T> Debug for std::sync::nonpoison::rwlock::MappedRwLockReadGuard<'_, T>
where T: Debug + ?Sized,

Source

impl<T> Debug for std::sync::poison::rwlock::MappedRwLockReadGuard<'_, T>
where T: Debug + ?Sized,

Source

impl<T> Debug for std::sync::nonpoison::rwlock::MappedRwLockWriteGuard<'_, T>
where T: Debug + ?Sized,

Source

impl<T> Debug for std::sync::poison::rwlock::MappedRwLockWriteGuard<'_, T>
where T: Debug + ?Sized,

1.41.0 · Source

impl<T> Debug for MaybeUninit<T>

Source

impl<T> Debug for std::sync::nonpoison::mutex::Mutex<T>
where T: Debug + ?Sized,

1.0.0 · Source

impl<T> Debug for std::sync::poison::mutex::Mutex<T>
where T: Debug + ?Sized,

Source

impl<T> Debug for std::sync::nonpoison::mutex::MutexGuard<'_, T>
where T: Debug + ?Sized,

1.16.0 · Source

impl<T> Debug for std::sync::poison::mutex::MutexGuard<'_, T>
where T: Debug + ?Sized,

1.25.0 · Source

impl<T> Debug for NonNull<T>
where T: ?Sized,

1.28.0 · Source

impl<T> Debug for NonZero<T>

1.98.0 · Source

impl<T> Debug for NumBuffer<T>
where T: NumBufferTrait,

1.2.0 · Source

impl<T> Debug for core::iter::sources::once::Once<T>
where T: Debug,

1.70.0 · Source

impl<T> Debug for OnceCell<T>
where T: Debug,

1.70.0 · Source

impl<T> Debug for OnceLock<T>
where T: Debug,

1.0.0 · Source

impl<T> Debug for Option<T>
where T: Debug,

1.48.0 · Source

impl<T> Debug for Pending<T>

Source

impl<T> Debug for PhantomContravariant<T>
where T: ?Sized,

Source

impl<T> Debug for PhantomCovariant<T>
where T: ?Sized,

1.0.0 · Source

impl<T> Debug for PhantomData<T>
where T: ?Sized,

Source

impl<T> Debug for PhantomInvariant<T>
where T: ?Sized,

1.0.0 · Source

impl<T> Debug for PoisonError<T>

1.36.0 · Source

impl<T> Debug for Poll<T>
where T: Debug,

1.48.0 · Source

impl<T> Debug for Ready<T>
where T: Debug,

Source

impl<T> Debug for std::sync::mpmc::Receiver<T>

1.8.0 · Source

impl<T> Debug for std::sync::mpsc::Receiver<T>

Source

impl<T> Debug for std::sync::oneshot::Receiver<T>

Source

impl<T> Debug for std::sync::oneshot::RecvTimeoutError<T>

Source

impl<T> Debug for ReentrantLock<T>
where T: Debug + ?Sized,

Source

impl<T> Debug for ReentrantLockGuard<'_, T>
where T: Debug + ?Sized,

1.0.0 · Source

impl<T> Debug for Ref<'_, T>
where T: Debug + ?Sized,

1.0.0 · Source

impl<T> Debug for RefCell<T>
where T: Debug + ?Sized,

1.0.0 · Source

impl<T> Debug for RefMut<'_, T>
where T: Debug + ?Sized,

1.0.0 · Source

impl<T> Debug for Rev<T>
where T: Debug,

1.19.0 · Source

impl<T> Debug for Reverse<T>
where T: Debug,

Source

impl<T> Debug for std::sync::nonpoison::rwlock::RwLock<T>
where T: Debug + ?Sized,

1.0.0 · Source

impl<T> Debug for std::sync::poison::rwlock::RwLock<T>
where T: Debug + ?Sized,

Source

impl<T> Debug for std::sync::nonpoison::rwlock::RwLockReadGuard<'_, T>
where T: Debug + ?Sized,

1.16.0 · Source

impl<T> Debug for std::sync::poison::rwlock::RwLockReadGuard<'_, T>
where T: Debug + ?Sized,

Source

impl<T> Debug for std::sync::nonpoison::rwlock::RwLockWriteGuard<'_, T>
where T: Debug + ?Sized,

1.16.0 · Source

impl<T> Debug for std::sync::poison::rwlock::RwLockWriteGuard<'_, T>
where T: Debug + ?Sized,

1.74.0 · Source

impl<T> Debug for Saturating<T>
where T: Debug,

1.0.0 · Source

impl<T> Debug for SendError<T>

Source

impl<T> Debug for SendTimeoutError<T>

Source

impl<T> Debug for std::sync::mpmc::Sender<T>

1.8.0 · Source

impl<T> Debug for std::sync::mpsc::Sender<T>

Source

impl<T> Debug for std::sync::oneshot::Sender<T>

1.17.0 · Source

impl<T> Debug for aidoku::alloc::collections::btree_set::SymmetricDifference<'_, T>
where T: Debug,

1.8.0 · Source

impl<T> Debug for SyncSender<T>

Source

impl<T> Debug for SyncUnsafeCell<T>
where T: ?Sized,

Source

impl<T> Debug for SyncView<T>
where T: ?Sized,

1.0.0 · Source

impl<T> Debug for aidoku::alloc::io::Take<T>
where T: Debug,

Source

impl<T> Debug for ThinBox<T>
where T: Debug + ?Sized,

Source

impl<T> Debug for TraitImpl<T>
where T: Debug + ?Sized,

1.0.0 · Source

impl<T> Debug for std::sync::poison::TryLockError<T>

Source

impl<T> Debug for std::sync::oneshot::TryRecvError<T>

1.0.0 · Source

impl<T> Debug for TrySendError<T>

1.17.0 · Source

impl<T> Debug for aidoku::alloc::collections::btree_set::Union<'_, T>
where T: Debug,

1.9.0 · Source

impl<T> Debug for UnsafeCell<T>
where T: ?Sized,

Source

impl<T> Debug for UnsafePinned<T>
where T: ?Sized,

1.0.0 · Source

impl<T> Debug for Wrapping<T>
where T: Debug,

Source

impl<T> Debug for Yeet<T>
where T: Debug,

1.0.0 · Source

impl<T> Debug for [T]
where T: Debug,

1.0.0 · Source

impl<W> Debug for BufWriter<W>
where W: Write + Debug + ?Sized,

1.0.0 · Source

impl<W> Debug for IntoInnerError<W>
where W: Debug,

1.0.0 · Source

impl<W> Debug for LineWriter<W>
where W: Write + Debug + ?Sized,

Source

impl<Y, R> Debug for CoroutineState<Y, R>
where Y: Debug, R: Debug,



impl<const N: usize> Debug for String<N>