Debug

Trait Debug 

1.0.0 · Source
pub trait Debug {
    // Required method
    fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>;
}
? formatting.

Debug should format the output in a programmer-facing, debugging context.

Generally speaking, you should just derive a Debug implementation.

When used with the alternate format specifier #?, the output is pretty-printed.

For more information on formatters, see the module-level documentation.

This trait can be used with #[derive] if all fields implement Debug. When derived for structs, it will use the name of the struct, then {, then a comma-separated list of each field’s name and Debug value, then }. For enums, it will use the name of the variant and, if applicable, (, then the Debug values of the fields, then ).

Stability

Derived Debug formats are not stable, and so may change with future Rust versions. Additionally, Debug implementations of types provided by the standard library (std, core, alloc, etc.) are not stable, and may also change with future Rust versions.

Examples

Deriving an implementation:

#[derive(Debug)]
struct Point {
    x: i32,
    y: i32,
}

let origin = Point { x: 0, y: 0 };

assert_eq!(
    format!("The origin is: {origin:?}"),
    "The origin is: Point { x: 0, y: 0 }",
);

Manually implementing:

use std::fmt;

struct Point {
    x: i32,
    y: i32,
}

impl fmt::Debug for Point {
    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
        f.debug_struct("Point")
         .field("x", &self.x)
         .field("y", &self.y)
         .finish()
    }
}

let origin = Point { x: 0, y: 0 };

assert_eq!(
    format!("The origin is: {origin:?}"),
    "The origin is: Point { x: 0, y: 0 }",
);

There are a number of helper methods on the Formatter struct to help you with manual implementations, such as debug_struct.

Types that do not wish to use the standard suite of debug representations provided by the Formatter trait (debug_struct, debug_tuple, debug_list, debug_set, debug_map) can do something totally custom by manually writing an arbitrary representation to the Formatter.

impl fmt::Debug for Point {
    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
        write!(f, "Point [{} {}]", self.x, self.y)
    }
}

Debug implementations using either derive or the debug builder API on Formatter support pretty-printing using the alternate flag: {:#?}.

Pretty-printing with #?:

#[derive(Debug)]
struct Point {
    x: i32,
    y: i32,
}

let origin = Point { x: 0, y: 0 };

let expected = "The origin is: Point {
    x: 0,
    y: 0,
}";
assert_eq!(format!("The origin is: {origin:#?}"), expected);

Required Methods

1.0.0 · Source

fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>

Formats the value using the given formatter.

Errors

This function should return Err if, and only if, the provided Formatter returns Err. String formatting is considered an infallible operation; this function only returns a Result because writing to the underlying stream might fail and it must provide a way to propagate the fact that an error has occurred back up the stack.

Examples
use std::fmt;

struct Position {
    longitude: f32,
    latitude: f32,
}

impl fmt::Debug for Position {
    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
        f.debug_tuple("")
         .field(&self.longitude)
         .field(&self.latitude)
         .finish()
    }
}

let position = Position { longitude: 1.987, latitude: 2.983 };
assert_eq!(format!("{position:?}"), "(1.987, 2.983)");

assert_eq!(format!("{position:#?}"), "(
    1.987,
    2.983,
)");

Implementors

Source

impl Debug for FontWeight

Source

impl Debug for LineCap

Source

impl Debug for LineJoin

Source

impl Debug for PathOp

Source

impl Debug for ContentRating

Source

impl Debug for DeepLinkResult

Source

impl Debug for FilterKind

Source

impl Debug for FilterValue

Source

impl Debug for HomeComponentValue

Source

impl Debug for HomePartialResult

Source

impl Debug for LinkValue

Source

impl Debug for ListingKind

Source

impl Debug for LoginMethod

Source

impl Debug for MangaStatus

Source

impl Debug for PageContent

Source

impl Debug for PageIcon

Source

impl Debug for SettingValue

Source

impl Debug for UpdateStrategy

Source

impl Debug for Viewer

Source

impl Debug for SerializeError

Source

impl Debug for CanvasError

Source

impl Debug for AidokuError

Source

impl Debug for HtmlError

Source

impl Debug for JsError

Source

impl Debug for HttpMethod

Source

impl Debug for RequestError

Source

impl Debug for StdError

Source

impl Debug for aidoku::alloc::collections::TryReserveErrorKind

1.86.0 · Source

impl Debug for GetDisjointMutError

Source

impl Debug for SearchStep

1.28.0 · Source

impl Debug for aidoku::alloc::fmt::Alignment

Source

impl Debug for DebugAsHex

Source

impl Debug for Sign

Source

impl Debug for AsciiChar

1.0.0 · Source

impl Debug for core::cmp::Ordering

1.34.0 · Source

impl Debug for Infallible

1.64.0 · Source

impl Debug for FromBytesWithNulError

1.16.0 · Source

impl Debug for c_void

Source

impl Debug for AtomicOrdering

Source

impl Debug for SimdAlign

1.7.0 · Source

impl Debug for IpAddr

Source

impl Debug for Ipv6MulticastScope

1.0.0 · Source

impl Debug for core::net::socket_addr::SocketAddr

1.0.0 · Source

impl Debug for FpCategory

1.55.0 · Source

impl Debug for IntErrorKind

1.0.0 · Source

impl Debug for core::sync::atomic::Ordering

1.65.0 · Source

impl Debug for BacktraceStatus

1.0.0 · Source

impl Debug for VarError

1.89.0 · Source

impl Debug for std::fs::TryLockError

1.0.0 · Source

impl Debug for SeekFrom

1.0.0 · Source

impl Debug for ErrorKind

1.0.0 · Source

impl Debug for Shutdown

Source

impl Debug for AncillaryError

Source

impl Debug for BacktraceStyle

1.12.0 · Source

impl Debug for RecvTimeoutError

1.0.0 · Source

impl Debug for TryRecvError

Source

impl Debug for FloatErrorKind

Source

impl Debug for Always

Source

impl Debug for OnSuccess

Source

impl Debug for OnUnwind

1.0.0 · Source

impl Debug for bool

1.0.0 · Source

impl Debug for char

1.0.0 · Source

impl Debug for f16

1.0.0 · Source

impl Debug for f32

1.0.0 · Source

impl Debug for f64

1.0.0 · Source

impl Debug for f128

1.0.0 · Source

impl Debug for i8

1.0.0 · Source

impl Debug for i16

1.0.0 · Source

impl Debug for i32

1.0.0 · Source

impl Debug for i64

1.0.0 · Source

impl Debug for i128

1.0.0 · Source

impl Debug for isize

Source

impl Debug for !

1.0.0 · Source

impl Debug for str

1.0.0 · Source

impl Debug for u8

1.0.0 · Source

impl Debug for u16

1.0.0 · Source

impl Debug for u32

1.0.0 · Source

impl Debug for u64

1.0.0 · Source

impl Debug for u128

1.0.0 · Source

impl Debug for ()

1.0.0 · Source

impl Debug for usize

Source

impl Debug for Color

Source

impl Debug for aidoku::canvas::Path

Source

impl Debug for PathBuilder

Source

impl Debug for Point

Source

impl Debug for aidoku::canvas::Rect

Source

impl Debug for StrokeStyle

Source

impl Debug for QueryParameters

Source

impl Debug for Canvas

Source

impl Debug for Font

Source

impl Debug for ImageRef

Source

impl Debug for Html

Source

impl Debug for aidoku::imports::net::Request

Source

impl Debug for Response

Source

impl Debug for ButtonSetting

Source

impl Debug for Chapter

Source

impl Debug for CheckFilter

Source

impl Debug for EditableListSetting

Source

impl Debug for aidoku::Filter

Source

impl Debug for FilterItem

Source

impl Debug for GroupSetting

Source

impl Debug for HomeComponent

Source

impl Debug for HomeLayout

Source

impl Debug for ImageRequest

Source

impl Debug for ImageResponse

Source

impl Debug for LinkSetting

Source

impl Debug for Listing

Source

impl Debug for LoginSetting

Source

impl Debug for Manga

Source

impl Debug for MangaPageResult

Source

impl Debug for MangaWithChapter

Source

impl Debug for MultiSelectFilter

Source

impl Debug for MultiSelectSetting

Source

impl Debug for Page

Source

impl Debug for PageSetting

Source

impl Debug for RangeFilter

Source

impl Debug for SegmentSetting

Source

impl Debug for SelectFilter

Source

impl Debug for SelectSetting

Source

impl Debug for Setting

Source

impl Debug for SortFilter

Source

impl Debug for SortFilterDefault

Source

impl Debug for StepperSetting

Source

impl Debug for TextFilter

Source

impl Debug for TextSetting

Source

impl Debug for ToggleSetting

Source

impl Debug for ByteStr

Source

impl Debug for ByteString

Source

impl Debug for UnorderedKeyError

1.57.0 · Source

impl Debug for aidoku::alloc::collections::TryReserveError

1.0.0 · Source

impl Debug for CString

Delegates to the CStr implementation of fmt::Debug, showing invalid UTF-8 as hex escapes.

1.64.0 · Source

impl Debug for FromVecWithNulError

1.64.0 · Source

impl Debug for IntoStringError

1.64.0 · Source

impl Debug for NulError

1.38.0 · Source

impl Debug for Chars<'_>

1.17.0 · Source

impl Debug for EncodeUtf16<'_>

1.0.0 · Source

impl Debug for ParseBoolError

1.79.0 · Source

impl Debug for Utf8Chunks<'_>

1.0.0 · Source

impl Debug for Utf8Error

1.17.0 · Source

impl Debug for aidoku::alloc::string::Drain<'_>

1.0.0 · Source

impl Debug for FromUtf8Error

1.0.0 · Source

impl Debug for FromUtf16Error

Source

impl Debug for IntoChars

1.0.0 · Source

impl Debug for aidoku::alloc::String

Source

impl Debug for alloc::alloc::Global

1.28.0 · Source

impl Debug for Layout

1.50.0 · Source

impl Debug for LayoutError

Source

impl Debug for core::alloc::AllocError

1.0.0 · Source

impl Debug for TypeId

1.34.0 · Source

impl Debug for TryFromSliceError

1.16.0 · Source

impl Debug for core::ascii::EscapeDefault

1.13.0 · Source

impl Debug for BorrowError

1.13.0 · Source

impl Debug for BorrowMutError

1.34.0 · Source

impl Debug for CharTryFromError

1.20.0 · Source

impl Debug for ParseCharError

1.9.0 · Source

impl Debug for DecodeUtf16Error

1.20.0 · Source

impl Debug for core::char::EscapeDebug

1.0.0 · Source

impl Debug for core::char::EscapeDefault

1.0.0 · Source

impl Debug for core::char::EscapeUnicode

1.0.0 · Source

impl Debug for ToLowercase

1.0.0 · Source

impl Debug for ToUppercase

1.59.0 · Source

impl Debug for TryFromCharError

1.27.0 · Source

impl Debug for CpuidResult

1.27.0 · Source

impl Debug for __m128

1.89.0 · Source

impl Debug for __m128bh

1.27.0 · Source

impl Debug for __m128d

Source

impl Debug for __m128h

1.27.0 · Source

impl Debug for __m128i

1.27.0 · Source

impl Debug for __m256

1.89.0 · Source

impl Debug for __m256bh

1.27.0 · Source

impl Debug for __m256d

Source

impl Debug for __m256h

1.27.0 · Source

impl Debug for __m256i

1.72.0 · Source

impl Debug for __m512

1.89.0 · Source

impl Debug for __m512bh

1.72.0 · Source

impl Debug for __m512d

Source

impl Debug for __m512h

1.72.0 · Source

impl Debug for __m512i

Source

impl Debug for bf16

1.3.0 · Source

impl Debug for CStr

Shows the underlying bytes as a normal string, with invalid UTF-8 presented as hex escape sequences.

1.69.0 · Source

impl Debug for FromBytesUntilNulError

1.0.0 · Source

impl Debug for SipHasher

Source

impl Debug for Last

Source

impl Debug for BorrowedBuf<'_>

1.33.0 · Source

impl Debug for PhantomPinned

Source

impl Debug for PhantomContravariantLifetime<'_>

Source

impl Debug for PhantomCovariantLifetime<'_>

Source

impl Debug for PhantomInvariantLifetime<'_>

Source

impl Debug for Assume

1.0.0 · Source

impl Debug for Ipv4Addr

1.0.0 · Source

impl Debug for Ipv6Addr

1.0.0 · Source

impl Debug for AddrParseError

1.0.0 · Source

impl Debug for SocketAddrV4

1.0.0 · Source

impl Debug for SocketAddrV6

1.0.0 · Source

impl Debug for core::num::dec2flt::ParseFloatError

1.0.0 · Source

impl Debug for ParseIntError

1.34.0 · Source

impl Debug for TryFromIntError

1.0.0 · Source

impl Debug for RangeFull

1.10.0 · Source

impl Debug for Location<'_>

1.81.0 · Source

impl Debug for PanicMessage<'_>

Source

impl Debug for core::ptr::alignment::Alignment

1.3.0 · Source

impl Debug for AtomicBool

Available on target_has_atomic_load_store=8 only.
1.34.0 · Source

impl Debug for AtomicI8

1.34.0 · Source

impl Debug for AtomicI16

1.34.0 · Source

impl Debug for AtomicI32

1.34.0 · Source

impl Debug for AtomicI64

1.3.0 · Source

impl Debug for AtomicIsize

1.34.0 · Source

impl Debug for AtomicU8

1.34.0 · Source

impl Debug for AtomicU16

1.34.0 · Source

impl Debug for AtomicU32

1.34.0 · Source

impl Debug for AtomicU64

1.3.0 · Source

impl Debug for AtomicUsize

1.36.0 · Source

impl Debug for Context<'_>

Source

impl Debug for LocalWaker

1.36.0 · Source

impl Debug for RawWaker

1.36.0 · Source

impl Debug for RawWakerVTable

1.36.0 · Source

impl Debug for Waker

1.27.0 · Source

impl Debug for Duration

1.66.0 · Source

impl Debug for TryFromFloatSecsError

1.28.0 · Source

impl Debug for System

1.65.0 · Source

impl Debug for Backtrace

Source

impl Debug for BacktraceFrame

1.16.0 · Source

impl Debug for Args

1.16.0 · Source

impl Debug for ArgsOs

1.0.0 · Source

impl Debug for JoinPathsError

1.16.0 · Source

impl Debug for SplitPaths<'_>

1.16.0 · Source

impl Debug for Vars

1.16.0 · Source

impl Debug for VarsOs

1.87.0 · Source

impl Debug for std::ffi::os_str::Display<'_>

1.0.0 · Source

impl Debug for OsStr

1.0.0 · Source

impl Debug for OsString

1.6.0 · Source

impl Debug for DirBuilder

1.13.0 · Source

impl Debug for DirEntry

1.0.0 · Source

impl Debug for File

1.75.0 · Source

impl Debug for FileTimes

1.16.0 · Source

impl Debug for FileType

1.16.0 · Source

impl Debug for Metadata

1.0.0 · Source

impl Debug for OpenOptions

1.0.0 · Source

impl Debug for Permissions

1.0.0 · Source

impl Debug for ReadDir

1.7.0 · Source

impl Debug for DefaultHasher

1.16.0 · Source

impl Debug for std::hash::random::RandomState

1.56.0 · Source

impl Debug for WriterPanicked

1.0.0 · Source

impl Debug for std::io::error::Error

1.87.0 · Source

impl Debug for PipeReader

1.87.0 · Source

impl Debug for PipeWriter

1.16.0 · Source

impl Debug for Stderr

1.16.0 · Source

impl Debug for StderrLock<'_>

1.16.0 · Source

impl Debug for Stdin

1.16.0 · Source

impl Debug for StdinLock<'_>

1.16.0 · Source

impl Debug for Stdout

1.16.0 · Source

impl Debug for StdoutLock<'_>

1.0.0 · Source

impl Debug for std::io::util::Empty

1.16.0 · Source

impl Debug for std::io::util::Repeat

1.0.0 · Source

impl Debug for Sink

Source

impl Debug for IntoIncoming

1.0.0 · Source

impl Debug for TcpListener

1.0.0 · Source

impl Debug for TcpStream

1.0.0 · Source

impl Debug for UdpSocket

1.63.0 · Source

impl Debug for BorrowedFd<'_>

1.63.0 · Source

impl Debug for OwnedFd

Source

impl Debug for PidFd

1.10.0 · Source

impl Debug for std::os::unix::net::addr::SocketAddr

1.10.0 · Source

impl Debug for UnixDatagram

1.10.0 · Source

impl Debug for UnixListener

1.10.0 · Source

impl Debug for UnixStream

Source

impl Debug for UCred

1.13.0 · Source

impl Debug for Components<'_>

1.0.0 · Source

impl Debug for std::path::Display<'_>

1.13.0 · Source

impl Debug for std::path::Iter<'_>

Source

impl Debug for NormalizeError

1.0.0 · Source

impl Debug for std::path::Path

1.0.0 · Source

impl Debug for PathBuf

1.7.0 · Source

impl Debug for StripPrefixError

1.16.0 · Source

impl Debug for Child

1.16.0 · Source

impl Debug for ChildStderr

1.16.0 · Source

impl Debug for ChildStdin

1.16.0 · Source

impl Debug for ChildStdout

1.0.0 · Source

impl Debug for Command

1.61.0 · Source

impl Debug for ExitCode

1.0.0 · Source

impl Debug for ExitStatus

Source

impl Debug for ExitStatusError

1.7.0 · Source

impl Debug for Output

1.16.0 · Source

impl Debug for Stdio

Source

impl Debug for DefaultRandomSource

1.16.0 · Source

impl Debug for Barrier

1.16.0 · Source

impl Debug for BarrierWaitResult

1.0.0 · Source

impl Debug for RecvError

Source

impl Debug for std::sync::nonpoison::condvar::Condvar

Source

impl Debug for WouldBlock

1.16.0 · Source

impl Debug for std::sync::once::Once

1.16.0 · Source

impl Debug for OnceState

1.16.0 · Source

impl Debug for std::sync::poison::condvar::Condvar

1.5.0 · Source

impl Debug for WaitTimeoutResult

1.0.0 · Source

impl Debug for Builder

1.19.0 · Source

impl Debug for ThreadId

1.26.0 · Source

impl Debug for AccessError

1.63.0 · Source

impl Debug for Scope<'_, '_>

1.0.0 · Source

impl Debug for Thread

1.8.0 · Source

impl Debug for Instant

1.8.0 · Source

impl Debug for SystemTime

1.8.0 · Source

impl Debug for SystemTimeError

Source

impl Debug for num_traits::ParseFloatError

Source

impl Debug for IgnoredAny

Source

impl Debug for serde_core::de::value::Error

1.0.0 · Source

impl Debug for Arguments<'_>

1.0.0 · Source

impl Debug for aidoku::alloc::fmt::Error

Source

impl Debug for FormattingOptions



impl Debug for AllocError



impl Debug for BigEndian



impl Debug for BoolVector2D



impl Debug for BoolVector3D



impl Debug for DecodeError



impl Debug for DecodeReport



impl Debug for DecoderState



impl Debug for DefaultHashBuilder



impl Debug for DestBufTooSmallError



impl Debug for EncoderState



impl Debug for Error



impl Debug for FixedState



impl Debug for FixedState



impl Debug for Global



impl Debug for LinkedIndexU8



impl Debug for LinkedIndexU16



impl Debug for LinkedIndexUsize



impl Debug for LittleEndian



impl Debug for RandomState



impl Debug for RandomState



impl Debug for SeedableRandomState



impl Debug for SeedableRandomState



impl Debug for SharedSeed



impl Debug for Span



impl Debug for TryReserveError



impl Debug for TryReserveError



impl Debug for TryReserveErrorKind



impl Debug for UnknownUnit

1.0.0 · Source

impl Debug for dyn Any

1.0.0 · Source

impl Debug for dyn Any + Send

1.28.0 · Source

impl Debug for dyn Any + Send + Sync

Source

impl<'a> Debug for Utf8Pattern<'a>

1.0.0 · Source

impl<'a> Debug for Component<'a>

1.0.0 · Source

impl<'a> Debug for Prefix<'a>

Source

impl<'a> Debug for Unexpected<'a>

1.60.0 · Source

impl<'a> Debug for EscapeAscii<'a>

Source

impl<'a> Debug for CharSearcher<'a>

1.0.0 · Source

impl<'a> Debug for aidoku::alloc::str::Bytes<'a>

1.0.0 · Source

impl<'a> Debug for CharIndices<'a>

1.34.0 · Source

impl<'a> Debug for aidoku::alloc::str::EscapeDebug<'a>

1.34.0 · Source

impl<'a> Debug for aidoku::alloc::str::EscapeDefault<'a>

1.34.0 · Source

impl<'a> Debug for aidoku::alloc::str::EscapeUnicode<'a>

1.0.0 · Source

impl<'a> Debug for aidoku::alloc::str::Lines<'a>

1.0.0 · Source

impl<'a> Debug for LinesAny<'a>

1.34.0 · Source

impl<'a> Debug for SplitAsciiWhitespace<'a>

1.1.0 · Source

impl<'a> Debug for SplitWhitespace<'a>

1.79.0 · Source

impl<'a> Debug for Utf8Chunk<'a>

Source

impl<'a> Debug for core::error::Request<'a>

Source

impl<'a> Debug for Source<'a>

Source

impl<'a> Debug for core::ffi::c_str::Bytes<'a>

Source

impl<'a> Debug for BorrowedCursor<'a>

1.10.0 · Source

impl<'a> Debug for PanicInfo<'a>

Source

impl<'a> Debug for ContextBuilder<'a>

1.36.0 · Source

impl<'a> Debug for IoSlice<'a>

1.36.0 · Source

impl<'a> Debug for IoSliceMut<'a>

1.0.0 · Source

impl<'a> Debug for std::net::tcp::Incoming<'a>

Source

impl<'a> Debug for SocketAncillary<'a>

1.10.0 · Source

impl<'a> Debug for std::os::unix::net::listener::Incoming<'a>

1.81.0 · Source

impl<'a> Debug for PanicHookInfo<'a>

1.28.0 · Source

impl<'a> Debug for Ancestors<'a>

1.0.0 · Source

impl<'a> Debug for PrefixComponent<'a>

1.57.0 · Source

impl<'a> Debug for CommandArgs<'a>

1.57.0 · Source

impl<'a> Debug for CommandEnvs<'a>



impl<'a> Debug for CobsDecoder<'a>



impl<'a> Debug for CobsEncoder<'a>

Source

impl<'a, 'b> Debug for CharSliceSearcher<'a, 'b>

Source

impl<'a, 'b> Debug for StrSearcher<'a, 'b>

Source

impl<'a, 'b, const N: usize> Debug for CharArrayRefSearcher<'a, 'b, N>

Source

impl<'a, 'f> Debug for VaList<'a, 'f>
where 'f: 'a,

1.0.0 · Source

impl<'a, A> Debug for core::option::Iter<'a, A>
where A: Debug + 'a,

1.0.0 · Source

impl<'a, A> Debug for core::option::IterMut<'a, A>
where A: Debug + 'a,

Source

impl<'a, E> Debug for BytesDeserializer<'a, E>

Source

impl<'a, E> Debug for CowStrDeserializer<'a, E>

Available on crate features std or alloc only.
Source

impl<'a, E> Debug for StrDeserializer<'a, E>

Source

impl<'a, I> Debug for ByRefSized<'a, I>
where I: Debug,

1.21.0 · Source

impl<'a, I, A> Debug for aidoku::alloc::vec::Splice<'a, I, A>
where I: Debug + Iterator + 'a, A: Debug + Allocator + 'a, <I as Iterator>::Item: Debug,



impl<'a, I, A> Debug for Splice<'a, I, A>
where I: Debug + Iterator + 'a, A: Debug + Allocator + 'a, <I as Iterator>::Item: Debug,

1.5.0 · Source

impl<'a, P> Debug for MatchIndices<'a, P>
where P: Pattern, <P as Pattern>::Searcher<'a>: Debug,

1.2.0 · Source

impl<'a, P> Debug for Matches<'a, P>
where P: Pattern, <P as Pattern>::Searcher<'a>: Debug,

1.5.0 · Source

impl<'a, P> Debug for RMatchIndices<'a, P>
where P: Pattern, <P as Pattern>::Searcher<'a>: Debug,

1.2.0 · Source

impl<'a, P> Debug for RMatches<'a, P>
where P: Pattern, <P as Pattern>::Searcher<'a>: Debug,

1.0.0 · Source

impl<'a, P> Debug for aidoku::alloc::str::RSplit<'a, P>
where P: Pattern, <P as Pattern>::Searcher<'a>: Debug,

1.0.0 · Source

impl<'a, P> Debug for aidoku::alloc::str::RSplitN<'a, P>
where P: Pattern, <P as Pattern>::Searcher<'a>: Debug,

1.0.0 · Source

impl<'a, P> Debug for RSplitTerminator<'a, P>
where P: Pattern, <P as Pattern>::Searcher<'a>: Debug,

1.0.0 · Source

impl<'a, P> Debug for aidoku::alloc::str::Split<'a, P>
where P: Pattern, <P as Pattern>::Searcher<'a>: Debug,

1.51.0 · Source

impl<'a, P> Debug for aidoku::alloc::str::SplitInclusive<'a, P>
where P: Pattern, <P as Pattern>::Searcher<'a>: Debug,

1.0.0 · Source

impl<'a, P> Debug for aidoku::alloc::str::SplitN<'a, P>
where P: Pattern, <P as Pattern>::Searcher<'a>: Debug,

1.0.0 · Source

impl<'a, P> Debug for SplitTerminator<'a, P>
where P: Pattern, <P as Pattern>::Searcher<'a>: Debug,



impl<'a, R, G, T> Debug for MappedReentrantMutexGuard<'a, R, G, T>
where R: RawMutex + 'a, G: GetThreadId + 'a, T: Debug + 'a + ?Sized,



impl<'a, R, G, T> Debug for ReentrantMutexGuard<'a, R, G, T>
where R: RawMutex + 'a, G: GetThreadId + 'a, T: Debug + 'a + ?Sized,



impl<'a, R, T> Debug for MappedMutexGuard<'a, R, T>
where R: RawMutex + 'a, T: Debug + 'a + ?Sized,



impl<'a, R, T> Debug for MappedRwLockReadGuard<'a, R, T>
where R: RawRwLock + 'a, T: Debug + 'a + ?Sized,



impl<'a, R, T> Debug for MappedRwLockWriteGuard<'a, R, T>
where R: RawRwLock + 'a, T: Debug + 'a + ?Sized,



impl<'a, R, T> Debug for MutexGuard<'a, R, T>
where R: RawMutex + 'a, T: Debug + 'a + ?Sized,



impl<'a, R, T> Debug for RwLockReadGuard<'a, R, T>
where R: RawRwLock + 'a, T: Debug + 'a + ?Sized,



impl<'a, R, T> Debug for RwLockUpgradableReadGuard<'a, R, T>
where R: RawRwLockUpgrade + 'a, T: Debug + 'a + ?Sized,



impl<'a, R, T> Debug for RwLockWriteGuard<'a, R, T>
where R: RawRwLock + 'a, T: Debug + 'a + ?Sized,

1.17.0 · Source

impl<'a, T> Debug for aidoku::alloc::collections::btree_set::Range<'a, T>
where T: Debug + 'a,

1.0.0 · Source

impl<'a, T> Debug for Chunks<'a, T>
where T: Debug + 'a,

1.31.0 · Source

impl<'a, T> Debug for ChunksExact<'a, T>
where T: Debug + 'a,

1.31.0 · Source

impl<'a, T> Debug for ChunksExactMut<'a, T>
where T: Debug + 'a,

1.0.0 · Source

impl<'a, T> Debug for ChunksMut<'a, T>
where T: Debug + 'a,

1.31.0 · Source

impl<'a, T> Debug for RChunks<'a, T>
where T: Debug + 'a,

1.31.0 · Source

impl<'a, T> Debug for RChunksExact<'a, T>
where T: Debug + 'a,

1.31.0 · Source

impl<'a, T> Debug for RChunksExactMut<'a, T>
where T: Debug + 'a,

1.31.0 · Source

impl<'a, T> Debug for RChunksMut<'a, T>
where T: Debug + 'a,

1.0.0 · Source

impl<'a, T> Debug for Windows<'a, T>
where T: Debug + 'a,

1.0.0 · Source

impl<'a, T> Debug for core::result::Iter<'a, T>
where T: Debug + 'a,

1.0.0 · Source

impl<'a, T> Debug for core::result::IterMut<'a, T>
where T: Debug + 'a,

Source

impl<'a, T> Debug for std::sync::mpmc::Iter<'a, T>
where T: Debug + 'a,

Source

impl<'a, T> Debug for std::sync::mpmc::TryIter<'a, T>
where T: Debug + 'a,

1.0.0 · Source

impl<'a, T> Debug for std::sync::mpsc::Iter<'a, T>
where T: Debug + 'a,

1.15.0 · Source

impl<'a, T> Debug for std::sync::mpsc::TryIter<'a, T>
where T: Debug + 'a,



impl<'a, T> Debug for MutexGuard<'a, T>
where T: Debug + ?Sized,



impl<'a, T> Debug for SpinMutexGuard<'a, T>
where T: Debug + ?Sized,

1.6.0 · Source

impl<'a, T, A> Debug for aidoku::alloc::collections::binary_heap::Drain<'a, T, A>
where T: Debug + 'a, A: Debug + Allocator,

Source

impl<'a, T, A> Debug for DrainSorted<'a, T, A>
where T: Debug + Ord, A: Debug + Allocator,

1.77.0 · Source

impl<'a, T, P> Debug for ChunkBy<'a, T, P>
where T: 'a + Debug,

1.77.0 · Source

impl<'a, T, P> Debug for ChunkByMut<'a, T, P>
where T: 'a + Debug,

Source

impl<'a, T, const N: usize> Debug for ArrayWindows<'a, T, N>
where T: Debug + 'a,

Source

impl<'a, const N: usize> Debug for CharArraySearcher<'a, N>

Source

impl<'de, E> Debug for BorrowedBytesDeserializer<'de, E>

Source

impl<'de, E> Debug for BorrowedStrDeserializer<'de, E>

Source

impl<'de, I, E> Debug for MapDeserializer<'de, I, E>
where I: Iterator + Debug, <I as Iterator>::Item: Pair, <<I as Iterator>::Item as Pair>::Second: Debug,

Source

impl<'f> Debug for VaListImpl<'f>



impl<'rwlock, T> Debug for RwLockReadGuard<'rwlock, T>
where T: Debug + ?Sized,



impl<'rwlock, T, R> Debug for RwLockUpgradableGuard<'rwlock, T, R>
where T: Debug + ?Sized,



impl<'rwlock, T, R> Debug for RwLockWriteGuard<'rwlock, T, R>
where T: Debug + ?Sized,

1.63.0 · Source

impl<'scope, T> Debug for ScopedJoinHandle<'scope, T>

1.0.0 · Source

impl<A> Debug for core::iter::sources::repeat::Repeat<A>
where A: Debug,

1.82.0 · Source

impl<A> Debug for RepeatN<A>
where A: Debug,

1.0.0 · Source

impl<A> Debug for core::option::IntoIter<A>
where A: Debug,

Source

impl<A> Debug for RangeFromIter<A>
where A: Debug,

Source

impl<A> Debug for RangeInclusiveIter<A>
where A: Debug,

Source

impl<A> Debug for RangeIter<A>
where A: Debug,

Source

impl<A> Debug for EnumAccessDeserializer<A>
where A: Debug,

Source

impl<A> Debug for MapAccessDeserializer<A>
where A: Debug,

Source

impl<A> Debug for SeqAccessDeserializer<A>
where A: Debug,

1.0.0 · Source

impl<A, B> Debug for core::iter::adapters::chain::Chain<A, B>
where A: Debug, B: Debug,

1.0.0 · Source

impl<A, B> Debug for Zip<A, B>
where A: Debug, B: Debug,

1.0.0 · Source

impl<B> Debug for Cow<'_, B>
where B: Debug + ToOwned + ?Sized, <B as ToOwned>::Owned: Debug,

1.0.0 · Source

impl<B> Debug for std::io::Lines<B>
where B: Debug,

1.0.0 · Source

impl<B> Debug for std::io::Split<B>
where B: Debug,

1.55.0 · Source

impl<B, C> Debug for ControlFlow<B, C>
where B: Debug, C: Debug,

Source

impl<Dyn> Debug for DynMetadata<Dyn>
where Dyn: ?Sized,

Source

impl<E> Debug for Report<E>
where Report<E>: Display,

Source

impl<E> Debug for BoolDeserializer<E>

Source

impl<E> Debug for CharDeserializer<E>

Source

impl<E> Debug for F32Deserializer<E>

Source

impl<E> Debug for F64Deserializer<E>

Source

impl<E> Debug for I8Deserializer<E>

Source

impl<E> Debug for I16Deserializer<E>

Source

impl<E> Debug for I32Deserializer<E>

Source

impl<E> Debug for I64Deserializer<E>

Source

impl<E> Debug for I128Deserializer<E>

Source

impl<E> Debug for IsizeDeserializer<E>

Source

impl<E> Debug for StringDeserializer<E>

Available on crate features std or alloc only.
Source

impl<E> Debug for U8Deserializer<E>

Source

impl<E> Debug for U16Deserializer<E>

Source

impl<E> Debug for U32Deserializer<E>

Source

impl<E> Debug for U64Deserializer<E>

Source

impl<E> Debug for U128Deserializer<E>

Source

impl<E> Debug for UnitDeserializer<E>

Source

impl<E> Debug for UsizeDeserializer<E>

Source

impl<F> Debug for CharPredicateSearcher<'_, F>
where F: FnMut(char) -> bool,

1.64.0 · Source

impl<F> Debug for PollFn<F>

1.34.0 · Source

impl<F> Debug for core::iter::sources::from_fn::FromFn<F>

1.68.0 · Source

impl<F> Debug for OnceWith<F>

1.68.0 · Source

impl<F> Debug for RepeatWith<F>

1.93.0 · Source

impl<F> Debug for aidoku::alloc::fmt::FromFn<F>
where F: Fn(&mut Formatter<'_>) -> Result<(), Error>,

1.4.0 · Source

impl<F> Debug for F
where F: FnPtr,

Source

impl<G> Debug for FromCoroutine<G>

1.9.0 · Source

impl<H> Debug for core::hash::BuildHasherDefault<H>



impl<H> Debug for BuildHasherDefault<H>
where H: Default + Hasher,

Source

impl<I> Debug for FromIter<I>
where I: Debug,

1.9.0 · Source

impl<I> Debug for DecodeUtf16<I>
where I: Debug + Iterator<Item = u16>,

1.1.0 · Source

impl<I> Debug for Cloned<I>
where I: Debug,

1.36.0 · Source

impl<I> Debug for Copied<I>
where I: Debug,

1.0.0 · Source

impl<I> Debug for Cycle<I>
where I: Debug,

1.0.0 · Source

impl<I> Debug for Enumerate<I>
where I: Debug,

1.0.0 · Source

impl<I> Debug for Fuse<I>
where I: Debug,

Source

impl<I> Debug for Intersperse<I>
where I: Debug + Iterator, <I as Iterator>::Item: Clone + Debug,

1.0.0 · Source

impl<I> Debug for Peekable<I>
where I: Debug + Iterator, <I as Iterator>::Item: Debug,

1.0.0 · Source

impl<I> Debug for Skip<I>
where I: Debug,

1.28.0 · Source

impl<I> Debug for StepBy<I>
where I: Debug,

1.0.0 · Source

impl<I> Debug for core::iter::adapters::take::Take<I>
where I: Debug,

Source

impl<I, E> Debug for SeqDeserializer<I, E>
where I: Debug,

1.9.0 · Source

impl<I, F> Debug for FilterMap<I, F>
where I: Debug,

1.9.0 · Source

impl<I, F> Debug for Inspect<I, F>
where I: Debug,

1.9.0 · Source

impl<I, F> Debug for Map<I, F>
where I: Debug,

Source

impl<I, F, const N: usize> Debug for MapWindows<I, F, N>
where I: Iterator + Debug,

Source

impl<I, G> Debug for IntersperseWith<I, G>
where I: Iterator + Debug, <I as Iterator>::Item: Debug, G: Debug,

1.9.0 · Source

impl<I, P> Debug for core::iter::adapters::filter::Filter<I, P>
where I: Debug,

1.57.0 · Source

impl<I, P> Debug for MapWhile<I, P>
where I: Debug,

1.9.0 · Source

impl<I, P> Debug for SkipWhile<I, P>
where I: Debug,

1.9.0 · Source

impl<I, P> Debug for TakeWhile<I, P>
where I: Debug,

1.9.0 · Source

impl<I, St, F> Debug for Scan<I, St, F>
where I: Debug, St: Debug,

1.29.0 · Source

impl<I, U> Debug for Flatten<I>
where I: Debug + Iterator, <I as Iterator>::Item: IntoIterator<IntoIter = U, Item = <U as Iterator>::Item>, U: Debug + Iterator,

1.9.0 · Source

impl<I, U, F> Debug for FlatMap<I, U, F>
where I: Debug, U: IntoIterator, <U as IntoIterator>::IntoIter: Debug,

Source

impl<I, const N: usize> Debug for ArrayChunks<I, N>
where I: Debug + Iterator, <I as Iterator>::Item: Debug,

Source

impl<Idx> Debug for Clamp<Idx>
where Idx: Debug,

1.0.0 · Source

impl<Idx> Debug for core::ops::range::Range<Idx>
where Idx: Debug,

1.0.0 · Source

impl<Idx> Debug for core::ops::range::RangeFrom<Idx>
where Idx: Debug,

1.26.0 · Source

impl<Idx> Debug for core::ops::range::RangeInclusive<Idx>
where Idx: Debug,

1.0.0 · Source

impl<Idx> Debug for RangeTo<Idx>
where Idx: Debug,

1.26.0 · Source

impl<Idx> Debug for core::ops::range::RangeToInclusive<Idx>
where Idx: Debug,

Source

impl<Idx> Debug for core::range::Range<Idx>
where Idx: Debug,

Source

impl<Idx> Debug for core::range::RangeFrom<Idx>
where Idx: Debug,

Source

impl<Idx> Debug for core::range::RangeInclusive<Idx>
where Idx: Debug,

Source

impl<Idx> Debug for core::range::RangeToInclusive<Idx>
where Idx: Debug,

Source

impl<K> Debug for aidoku::alloc::collections::btree_set::Cursor<'_, K>
where K: Debug,

1.16.0 · Source

impl<K> Debug for std::collections::hash::set::Drain<'_, K>
where K: Debug,

1.16.0 · Source

impl<K> Debug for std::collections::hash::set::IntoIter<K>
where K: Debug,

1.16.0 · Source

impl<K> Debug for std::collections::hash::set::Iter<'_, K>
where K: Debug,



impl<K> Debug for Iter<'_, K>
where K: Debug,

Source

impl<K, A> Debug for aidoku::alloc::collections::btree_set::CursorMut<'_, K, A>
where K: Debug,

Source

impl<K, A> Debug for aidoku::alloc::collections::btree_set::CursorMutKey<'_, K, A>
where K: Debug,



impl<K, A> Debug for Drain<'_, K, A>
where K: Debug, A: Allocator,



impl<K, A> Debug for IntoIter<K, A>
where K: Debug, A: Allocator,

1.88.0 · Source

impl<K, F> Debug for std::collections::hash::set::ExtractIf<'_, K, F>
where K: Debug,



impl<K, Q, V, S, A> Debug for EntryRef<'_, '_, K, Q, V, S, A>
where K: Debug + Borrow<Q>, Q: Debug + ?Sized, V: Debug, A: Allocator,



impl<K, Q, V, S, A> Debug for VacantEntryRef<'_, '_, K, Q, V, S, A>
where K: Borrow<Q>, Q: Debug + ?Sized, A: Allocator,

1.12.0 · Source

impl<K, V> Debug for std::collections::hash::map::Entry<'_, K, V>
where K: Debug, V: Debug,

Source

impl<K, V> Debug for aidoku::alloc::collections::btree_map::Cursor<'_, K, V>
where K: Debug, V: Debug,

1.17.0 · Source

impl<K, V> Debug for aidoku::alloc::collections::btree_map::Iter<'_, K, V>
where K: Debug, V: Debug,

1.17.0 · Source

impl<K, V> Debug for aidoku::alloc::collections::btree_map::IterMut<'_, K, V>
where K: Debug, V: Debug,

1.17.0 · Source

impl<K, V> Debug for aidoku::alloc::collections::btree_map::Keys<'_, K, V>
where K: Debug,

1.17.0 · Source

impl<K, V> Debug for aidoku::alloc::collections::btree_map::Range<'_, K, V>
where K: Debug, V: Debug,

1.17.0 · Source

impl<K, V> Debug for RangeMut<'_, K, V>
where K: Debug, V: Debug,

1.17.0 · Source

impl<K, V> Debug for aidoku::alloc::collections::btree_map::Values<'_, K, V>
where V: Debug,

1.10.0 · Source

impl<K, V> Debug for aidoku::alloc::collections::btree_map::ValuesMut<'_, K, V>
where V: Debug,

1.16.0 · Source

impl<K, V> Debug for std::collections::hash::map::Drain<'_, K, V>
where K: Debug, V: Debug,

1.16.0 · Source

impl<K, V> Debug for std::collections::hash::map::IntoIter<K, V>
where K: Debug, V: Debug,

1.54.0 · Source

impl<K, V> Debug for std::collections::hash::map::IntoKeys<K, V>
where K: Debug,

1.54.0 · Source

impl<K, V> Debug for std::collections::hash::map::IntoValues<K, V>
where V: Debug,

1.16.0 · Source

impl<K, V> Debug for std::collections::hash::map::Iter<'_, K, V>
where K: Debug, V: Debug,

1.16.0 · Source

impl<K, V> Debug for std::collections::hash::map::IterMut<'_, K, V>
where K: Debug, V: Debug,

1.16.0 · Source

impl<K, V> Debug for std::collections::hash::map::Keys<'_, K, V>
where K: Debug,

1.12.0 · Source

impl<K, V> Debug for std::collections::hash::map::OccupiedEntry<'_, K, V>
where K: Debug, V: Debug,

Source

impl<K, V> Debug for std::collections::hash::map::OccupiedError<'_, K, V>
where K: Debug, V: Debug,

1.12.0 · Source

impl<K, V> Debug for std::collections::hash::map::VacantEntry<'_, K, V>
where K: Debug,

1.16.0 · Source

impl<K, V> Debug for std::collections::hash::map::Values<'_, K, V>
where V: Debug,

1.16.0 · Source

impl<K, V> Debug for std::collections::hash::map::ValuesMut<'_, K, V>
where V: Debug,



impl<K, V> Debug for Iter<'_, K, V>
where K: Debug, V: Debug,



impl<K, V> Debug for IterMut<'_, K, V>
where K: Debug, V: Debug,



impl<K, V> Debug for Keys<'_, K, V>
where K: Debug,



impl<K, V> Debug for Values<'_, K, V>
where V: Debug,



impl<K, V> Debug for ValuesMut<'_, K, V>
where V: Debug,

1.12.0 · Source

impl<K, V, A> Debug for aidoku::alloc::collections::btree_map::Entry<'_, K, V, A>
where K: Debug + Ord, V: Debug, A: Allocator + Clone,

Source

impl<K, V, A> Debug for aidoku::alloc::collections::btree_map::CursorMut<'_, K, V, A>
where K: Debug, V: Debug,

Source

impl<K, V, A> Debug for aidoku::alloc::collections::btree_map::CursorMutKey<'_, K, V, A>
where K: Debug, V: Debug,

1.17.0 · Source

impl<K, V, A> Debug for aidoku::alloc::collections::btree_map::IntoIter<K, V, A>
where K: Debug, V: Debug, A: Allocator + Clone,

1.54.0 · Source

impl<K, V, A> Debug for aidoku::alloc::collections::btree_map::IntoKeys<K, V, A>
where K: Debug, A: Allocator + Clone,

1.54.0 · Source

impl<K, V, A> Debug for aidoku::alloc::collections::btree_map::IntoValues<K, V, A>
where V: Debug, A: Allocator + Clone,

1.12.0 · Source

impl<K, V, A> Debug for aidoku::alloc::collections::btree_map::OccupiedEntry<'_, K, V, A>
where K: Debug + Ord, V: Debug, A: Allocator + Clone,

Source

impl<K, V, A> Debug for aidoku::alloc::collections::btree_map::OccupiedError<'_, K, V, A>
where K: Debug + Ord, V: Debug, A: Allocator + Clone,

1.12.0 · Source

impl<K, V, A> Debug for aidoku::alloc::collections::btree_map::VacantEntry<'_, K, V, A>
where K: Debug + Ord, A: Allocator + Clone,

1.0.0 · Source

impl<K, V, A> Debug for BTreeMap<K, V, A>
where K: Debug, V: Debug, A: Allocator + Clone,



impl<K, V, A> Debug for Drain<'_, K, V, A>
where K: Debug, V: Debug, A: Allocator,



impl<K, V, A> Debug for IntoIter<K, V, A>
where K: Debug, V: Debug, A: Allocator,



impl<K, V, A> Debug for IntoKeys<K, V, A>
where K: Debug, V: Debug, A: Allocator,



impl<K, V, A> Debug for IntoValues<K, V, A>
where V: Debug, A: Allocator,

1.88.0 · Source

impl<K, V, F> Debug for std::collections::hash::map::ExtractIf<'_, K, V, F>
where K: Debug, V: Debug,

1.91.0 · Source

impl<K, V, R, F, A> Debug for aidoku::alloc::collections::btree_map::ExtractIf<'_, K, V, R, F, A>
where K: Debug, V: Debug, A: Allocator + Clone,

1.0.0 · Source

impl<K, V, S> Debug for std::collections::hash::map::HashMap<K, V, S>
where K: Debug, V: Debug,



impl<K, V, S, A> Debug for aidoku::HashMap<K, V, S, A>
where K: Debug, V: Debug, A: Allocator,



impl<K, V, S, A> Debug for Entry<'_, K, V, S, A>
where K: Debug, V: Debug, A: Allocator,



impl<K, V, S, A> Debug for OccupiedEntry<'_, K, V, S, A>
where K: Debug, V: Debug, A: Allocator,



impl<K, V, S, A> Debug for OccupiedError<'_, K, V, S, A>
where K: Debug, V: Debug, A: Allocator,



impl<K, V, S, A> Debug for RawEntryBuilder<'_, K, V, S, A>
where A: Allocator,



impl<K, V, S, A> Debug for RawEntryBuilderMut<'_, K, V, S, A>
where A: Allocator,



impl<K, V, S, A> Debug for RawEntryMut<'_, K, V, S, A>
where K: Debug, V: Debug, A: Allocator,



impl<K, V, S, A> Debug for RawOccupiedEntryMut<'_, K, V, S, A>
where K: Debug, V: Debug, A: Allocator,



impl<K, V, S, A> Debug for RawVacantEntryMut<'_, K, V, S, A>
where A: Allocator,



impl<K, V, S, A> Debug for VacantEntry<'_, K, V, S, A>
where K: Debug, A: Allocator,



impl<K, V, S, const N: usize> Debug for IndexMap<K, V, S, N>
where K: Eq + Hash + Debug, V: Debug, S: BuildHasher,



impl<K, V, const N: usize> Debug for LinearMap<K, V, N>
where K: Eq + Debug, V: Debug,



impl<O> Debug for Talc<O>
where O: OomHandler,



impl<P> Debug for Arc<P>
where P: Pool, <P as Pool>::Data: Debug,



impl<P> Debug for Box<P>
where P: Pool, <P as Pool>::Data: Debug,

1.33.0 · Source

impl<Ptr> Debug for Pin<Ptr>
where Ptr: Debug,

1.0.0 · Source

impl<R> Debug for BufReader<R>
where R: Debug + ?Sized,

1.0.0 · Source

impl<R> Debug for std::io::Bytes<R>
where R: Debug,



impl<R, G, T> Debug for ReentrantMutex<R, G, T>
where R: RawMutex, G: GetThreadId, T: Debug + ?Sized,



impl<R, O> Debug for Talck<R, O>
where R: Debug + RawMutex, O: Debug + OomHandler,



impl<R, T> Debug for Mutex<R, T>
where R: RawMutex, T: Debug + ?Sized,



impl<R, T> Debug for RwLock<R, T>
where R: RawRwLock, T: Debug + ?Sized,

1.17.0 · Source

impl<T> Debug for Bound<T>
where T: Debug,

1.0.0 · Source

impl<T> Debug for Option<T>
where T: Debug,

1.36.0 · Source

impl<T> Debug for Poll<T>
where T: Debug,

Source

impl<T> Debug for SendTimeoutError<T>

1.0.0 · Source

impl<T> Debug for TrySendError<T>

1.0.0 · Source

impl<T> Debug for std::sync::poison::TryLockError<T>

1.0.0 · Source

impl<T> Debug for *const T
where T: ?Sized,

1.0.0 · Source

impl<T> Debug for *mut T
where T: ?Sized,

1.0.0 · Source

impl<T> Debug for &T
where T: Debug + ?Sized,

1.0.0 · Source

impl<T> Debug for &mut T
where T: Debug + ?Sized,

1.0.0 · Source

impl<T> Debug for [T]
where T: Debug,

1.0.0 · Source

impl<T> Debug for (T₁, T₂, …, Tₙ)
where T: Debug,

This trait is implemented for tuples up to twelve items long.

Source

impl<T> Debug for ThinBox<T>
where T: Debug + ?Sized,

1.17.0 · Source

impl<T> Debug for aidoku::alloc::collections::binary_heap::Iter<'_, T>
where T: Debug,

1.17.0 · Source

impl<T> Debug for aidoku::alloc::collections::btree_set::Iter<'_, T>
where T: Debug,

1.17.0 · Source

impl<T> Debug for aidoku::alloc::collections::btree_set::SymmetricDifference<'_, T>
where T: Debug,

1.17.0 · Source

impl<T> Debug for aidoku::alloc::collections::btree_set::Union<'_, T>
where T: Debug,

1.17.0 · Source

impl<T> Debug for aidoku::alloc::collections::linked_list::Iter<'_, T>
where T: Debug,

1.17.0 · Source

impl<T> Debug for aidoku::alloc::collections::linked_list::IterMut<'_, T>
where T: Debug,

1.17.0 · Source

impl<T> Debug for aidoku::alloc::collections::vec_deque::Iter<'_, T>
where T: Debug,

1.17.0 · Source

impl<T> Debug for aidoku::alloc::collections::vec_deque::IterMut<'_, T>
where T: Debug,

1.9.0 · Source

impl<T> Debug for aidoku::alloc::slice::Iter<'_, T>
where T: Debug,

1.9.0 · Source

impl<T> Debug for aidoku::alloc::slice::IterMut<'_, T>
where T: Debug,

1.70.0 · Source

impl<T> Debug for OnceCell<T>
where T: Debug,

1.0.0 · Source

impl<T> Debug for Cell<T>
where T: Copy + Debug,

1.0.0 · Source

impl<T> Debug for Ref<'_, T>
where T: Debug + ?Sized,

1.0.0 · Source

impl<T> Debug for RefCell<T>
where T: Debug + ?Sized,

1.0.0 · Source

impl<T> Debug for RefMut<'_, T>
where T: Debug + ?Sized,

Source

impl<T> Debug for SyncUnsafeCell<T>
where T: ?Sized,

1.9.0 · Source

impl<T> Debug for UnsafeCell<T>
where T: ?Sized,

1.19.0 · Source

impl<T> Debug for Reverse<T>
where T: Debug,

Source

impl<T> Debug for NumBuffer<T>
where T: Debug + NumBufferTrait,

1.48.0 · Source

impl<T> Debug for Pending<T>

1.48.0 · Source

impl<T> Debug for Ready<T>
where T: Debug,

1.0.0 · Source

impl<T> Debug for Rev<T>
where T: Debug,

1.9.0 · Source

impl<T> Debug for core::iter::sources::empty::Empty<T>

1.2.0 · Source

impl<T> Debug for core::iter::sources::once::Once<T>
where T: Debug,

1.0.0 · Source

impl<T> Debug for PhantomData<T>
where T: ?Sized,

Source

impl<T> Debug for PhantomContravariant<T>
where T: ?Sized,

Source

impl<T> Debug for PhantomCovariant<T>
where T: ?Sized,

Source

impl<T> Debug for PhantomInvariant<T>
where T: ?Sized,

1.20.0 · Source

impl<T> Debug for ManuallyDrop<T>
where T: Debug + ?Sized,

1.21.0 · Source

impl<T> Debug for Discriminant<T>

1.28.0 · Source

impl<T> Debug for NonZero<T>

1.74.0 · Source

impl<T> Debug for Saturating<T>
where T: Debug,

1.0.0 · Source

impl<T> Debug for Wrapping<T>
where T: Debug,

Source

impl<T> Debug for Yeet<T>
where T: Debug,

1.16.0 · Source

impl<T> Debug for AssertUnwindSafe<T>
where T: Debug,

Source

impl<T> Debug for UnsafePinned<T>
where T: ?Sized,

1.25.0 · Source

impl<T> Debug for NonNull<T>
where T: ?Sized,

1.0.0 · Source

impl<T> Debug for core::result::IntoIter<T>
where T: Debug,

1.3.0 · Source

impl<T> Debug for AtomicPtr<T>

Available on target_has_atomic_load_store=ptr only.
Source

impl<T> Debug for Exclusive<T>
where T: ?Sized,

1.0.0 · Source

impl<T> Debug for std::io::cursor::Cursor<T>
where T: Debug,

1.0.0 · Source

impl<T> Debug for std::io::Take<T>
where T: Debug,

Source

impl<T> Debug for std::sync::mpmc::IntoIter<T>
where T: Debug,

Source

impl<T> Debug for std::sync::mpmc::Receiver<T>

Source

impl<T> Debug for std::sync::mpmc::Sender<T>

1.1.0 · Source

impl<T> Debug for std::sync::mpsc::IntoIter<T>
where T: Debug,

1.8.0 · Source

impl<T> Debug for std::sync::mpsc::Receiver<T>

1.0.0 · Source

impl<T> Debug for SendError<T>

1.8.0 · Source

impl<T> Debug for std::sync::mpsc::Sender<T>

1.8.0 · Source

impl<T> Debug for SyncSender<T>

Source

impl<T> Debug for std::sync::nonpoison::mutex::MappedMutexGuard<'_, T>
where T: Debug + ?Sized,

Source

impl<T> Debug for std::sync::nonpoison::mutex::Mutex<T>
where T: Debug + ?Sized,

Source

impl<T> Debug for std::sync::nonpoison::mutex::MutexGuard<'_, T>
where T: Debug + ?Sized,

Source

impl<T> Debug for std::sync::nonpoison::rwlock::MappedRwLockReadGuard<'_, T>
where T: Debug + ?Sized,

Source

impl<T> Debug for std::sync::nonpoison::rwlock::MappedRwLockWriteGuard<'_, T>
where T: Debug + ?Sized,

Source

impl<T> Debug for std::sync::nonpoison::rwlock::RwLock<T>
where T: Debug + ?Sized,

Source

impl<T> Debug for std::sync::nonpoison::rwlock::RwLockReadGuard<'_, T>
where T: Debug + ?Sized,

Source

impl<T> Debug for std::sync::nonpoison::rwlock::RwLockWriteGuard<'_, T>
where T: Debug + ?Sized,

1.70.0 · Source

impl<T> Debug for OnceLock<T>
where T: Debug,

Source

impl<T> Debug for std::sync::poison::mutex::MappedMutexGuard<'_, T>
where T: Debug + ?Sized,

1.0.0 · Source

impl<T> Debug for std::sync::poison::mutex::Mutex<T>
where T: Debug + ?Sized,

1.16.0 · Source

impl<T> Debug for std::sync::poison::mutex::MutexGuard<'_, T>
where T: Debug + ?Sized,

Source

impl<T> Debug for std::sync::poison::rwlock::MappedRwLockReadGuard<'_, T>
where T: Debug + ?Sized,

Source

impl<T> Debug for std::sync::poison::rwlock::MappedRwLockWriteGuard<'_, T>
where T: Debug + ?Sized,

1.0.0 · Source

impl<T> Debug for std::sync::poison::rwlock::RwLock<T>
where T: Debug + ?Sized,

1.16.0 · Source

impl<T> Debug for std::sync::poison::rwlock::RwLockReadGuard<'_, T>
where T: Debug + ?Sized,

1.16.0 · Source

impl<T> Debug for std::sync::poison::rwlock::RwLockWriteGuard<'_, T>
where T: Debug + ?Sized,

1.0.0 · Source

impl<T> Debug for PoisonError<T>

Source

impl<T> Debug for ReentrantLock<T>
where T: Debug + ?Sized,

Source

impl<T> Debug for ReentrantLockGuard<'_, T>
where T: Debug + ?Sized,

1.16.0 · Source

impl<T> Debug for JoinHandle<T>

1.16.0 · Source

impl<T> Debug for LocalKey<T>
where T: 'static,

1.41.0 · Source

impl<T> Debug for MaybeUninit<T>



impl<T> Debug for Angle<T>
where T: Debug,



impl<T> Debug for Box<T>
where T: Debug,



impl<T> Debug for Iter<'_, T>
where T: Debug,



impl<T> Debug for IterBuckets<'_, T>



impl<T> Debug for IterHash<'_, T>
where T: Debug,



impl<T> Debug for IterHashBuckets<'_, T>



impl<T> Debug for IterHashMut<'_, T>
where T: Debug,



impl<T> Debug for IterMut<'_, T>
where T: Debug,

Source

impl<T, A> Debug for aidoku::alloc::collections::btree_set::Entry<'_, T, A>
where T: Debug + Ord, A: Allocator + Clone,

1.17.0 · Source

impl<T, A> Debug for aidoku::alloc::collections::binary_heap::IntoIter<T, A>
where T: Debug, A: Allocator,

Source

impl<T, A> Debug for IntoIterSorted<T, A>
where T: Debug, A: Debug + Allocator,

1.17.0 · Source

impl<T, A> Debug for aidoku::alloc::collections::binary_heap::PeekMut<'_, T, A>
where T: Ord + Debug, A: Allocator,

1.17.0 · Source

impl<T, A> Debug for aidoku::alloc::collections::btree_set::Difference<'_, T, A>
where T: Debug, A: Allocator + Clone,

1.17.0 · Source

impl<T, A> Debug for aidoku::alloc::collections::btree_set::Intersection<'_, T, A>
where T: Debug, A: Allocator + Clone,

1.0.0 · Source

impl<T, A> Debug for aidoku::alloc::collections::btree_set::IntoIter<T, A>
where T: Debug, A: Debug + Allocator + Clone,

Source

impl<T, A> Debug for aidoku::alloc::collections::btree_set::OccupiedEntry<'_, T, A>
where T: Debug + Ord, A: Allocator + Clone,

Source

impl<T, A> Debug for aidoku::alloc::collections::btree_set::VacantEntry<'_, T, A>
where T: Debug + Ord, A: Allocator + Clone,

Source

impl<T, A> Debug for aidoku::alloc::collections::linked_list::Cursor<'_, T, A>
where T: Debug, A: Allocator,

Source

impl<T, A> Debug for aidoku::alloc::collections::linked_list::CursorMut<'_, T, A>
where T: Debug, A: Allocator,

1.17.0 · Source

impl<T, A> Debug for aidoku::alloc::collections::linked_list::IntoIter<T, A>
where T: Debug, A: Allocator,

1.0.0 · Source

impl<T, A> Debug for BTreeSet<T, A>
where T: Debug, A: Allocator + Clone,

1.4.0 · Source

impl<T, A> Debug for aidoku::alloc::collections::BinaryHeap<T, A>
where T: Debug, A: Allocator,

1.0.0 · Source

impl<T, A> Debug for LinkedList<T, A>
where T: Debug, A: Allocator,

1.0.0 · Source

impl<T, A> Debug for VecDeque<T, A>
where T: Debug, A: Allocator,

1.17.0 · Source

impl<T, A> Debug for aidoku::alloc::collections::vec_deque::Drain<'_, T, A>
where T: Debug, A: Allocator,

1.17.0 · Source

impl<T, A> Debug for aidoku::alloc::collections::vec_deque::IntoIter<T, A>
where T: Debug, A: Allocator,

1.0.0 · Source

impl<T, A> Debug for Rc<T, A>
where T: Debug + ?Sized, A: Allocator,

Source

impl<T, A> Debug for UniqueRc<T, A>
where T: Debug + ?Sized, A: Allocator,

1.4.0 · Source

impl<T, A> Debug for aidoku::alloc::rc::Weak<T, A>
where A: Allocator, T: ?Sized,

1.0.0 · Source

impl<T, A> Debug for aidoku::alloc::Box<T, A>
where T: Debug + ?Sized, A: Allocator,

1.0.0 · Source

impl<T, A> Debug for aidoku::alloc::Vec<T, A>
where T: Debug, A: Allocator,

1.0.0 · Source

impl<T, A> Debug for aidoku::alloc::sync::Arc<T, A>
where T: Debug + ?Sized, A: Allocator,

Source

impl<T, A> Debug for UniqueArc<T, A>
where T: Debug + ?Sized, A: Allocator,

1.4.0 · Source

impl<T, A> Debug for aidoku::alloc::sync::Weak<T, A>
where A: Allocator, T: ?Sized,

1.17.0 · Source

impl<T, A> Debug for aidoku::alloc::vec::Drain<'_, T, A>
where T: Debug, A: Allocator,

1.13.0 · Source

impl<T, A> Debug for aidoku::alloc::vec::IntoIter<T, A>
where T: Debug, A: Allocator,

Source

impl<T, A> Debug for aidoku::alloc::vec::PeekMut<'_, T, A>
where T: Debug, A: Allocator,



impl<T, A> Debug for AbsentEntry<'_, T, A>
where T: Debug, A: Allocator,



impl<T, A> Debug for Box<T, A>
where T: Debug + ?Sized, A: Allocator,



impl<T, A> Debug for Drain<'_, T, A>
where T: Debug, A: Allocator,



impl<T, A> Debug for Drain<'_, T, A>
where T: Debug, A: Allocator,



impl<T, A> Debug for Entry<'_, T, A>
where T: Debug, A: Allocator,



impl<T, A> Debug for HashTable<T, A>
where T: Debug, A: Allocator,



impl<T, A> Debug for IntoIter<T, A>
where T: Debug, A: Allocator,



impl<T, A> Debug for IntoIter<T, A>
where T: Debug, A: Allocator,



impl<T, A> Debug for OccupiedEntry<'_, T, A>
where T: Debug, A: Allocator,



impl<T, A> Debug for VacantEntry<'_, T, A>
where T: Debug, A: Allocator,



impl<T, A> Debug for Vec<T, A>
where T: Debug, A: Allocator,

1.0.0 · Source

impl<T, E> Debug for Result<T, E>
where T: Debug, E: Debug,

1.80.0 · Source

impl<T, F> Debug for LazyCell<T, F>
where T: Debug,

1.34.0 · Source

impl<T, F> Debug for Successors<T, F>
where T: Debug,

Source

impl<T, F> Debug for DropGuard<T, F>
where T: Debug, F: FnOnce(T),

1.80.0 · Source

impl<T, F> Debug for LazyLock<T, F>
where T: Debug,

1.87.0 · Source

impl<T, F, A> Debug for aidoku::alloc::collections::linked_list::ExtractIf<'_, T, F, A>
where T: Debug, A: Allocator,

Source

impl<T, F, A> Debug for aidoku::alloc::collections::vec_deque::ExtractIf<'_, T, F, A>
where T: Debug, A: Allocator,

1.87.0 · Source

impl<T, F, A> Debug for aidoku::alloc::vec::ExtractIf<'_, T, F, A>
where T: Debug, A: Allocator,



impl<T, F, R> Debug for Lazy<T, F, R>
where T: Debug,

Source

impl<T, F, S> Debug for ScopeGuard<T, F, S>
where T: Debug, F: FnOnce(T), S: Strategy,



impl<T, Idx, K, const N: usize> Debug for SortedLinkedList<T, Idx, K, N>
where T: Ord + Debug, Idx: SortedLinkedListIndex, K: Kind,



impl<T, K, const N: usize> Debug for BinaryHeap<T, K, N>
where K: Kind, T: Ord + Debug,

1.27.0 · Source

impl<T, P> Debug for aidoku::alloc::slice::RSplit<'_, T, P>
where T: Debug, P: FnMut(&T) -> bool,

1.27.0 · Source

impl<T, P> Debug for RSplitMut<'_, T, P>
where T: Debug, P: FnMut(&T) -> bool,

1.9.0 · Source

impl<T, P> Debug for aidoku::alloc::slice::RSplitN<'_, T, P>
where T: Debug, P: FnMut(&T) -> bool,

1.9.0 · Source

impl<T, P> Debug for RSplitNMut<'_, T, P>
where T: Debug, P: FnMut(&T) -> bool,

1.9.0 · Source

impl<T, P> Debug for aidoku::alloc::slice::Split<'_, T, P>
where T: Debug, P: FnMut(&T) -> bool,

1.51.0 · Source

impl<T, P> Debug for aidoku::alloc::slice::SplitInclusive<'_, T, P>
where T: Debug, P: FnMut(&T) -> bool,

1.51.0 · Source

impl<T, P> Debug for SplitInclusiveMut<'_, T, P>
where T: Debug, P: FnMut(&T) -> bool,

1.9.0 · Source

impl<T, P> Debug for SplitMut<'_, T, P>
where T: Debug, P: FnMut(&T) -> bool,

1.9.0 · Source

impl<T, P> Debug for aidoku::alloc::slice::SplitN<'_, T, P>
where T: Debug, P: FnMut(&T) -> bool,

1.9.0 · Source

impl<T, P> Debug for SplitNMut<'_, T, P>
where T: Debug, P: FnMut(&T) -> bool,



impl<T, R> Debug for Mutex<T, R>
where T: Debug + ?Sized,



impl<T, R> Debug for Once<T, R>
where T: Debug,



impl<T, R> Debug for RwLock<T, R>
where T: Debug + ?Sized,



impl<T, R> Debug for SpinMutex<T, R>
where T: Debug + ?Sized,

1.91.0 · Source

impl<T, R, F, A> Debug for aidoku::alloc::collections::btree_set::ExtractIf<'_, T, R, F, A>
where T: Debug, A: Allocator + Clone,

Source

impl<T, S> Debug for std::collections::hash::set::Entry<'_, T, S>
where T: Debug,

1.16.0 · Source

impl<T, S> Debug for std::collections::hash::set::Difference<'_, T, S>
where T: Debug + Eq + Hash, S: BuildHasher,

1.0.0 · Source

impl<T, S> Debug for std::collections::hash::set::HashSet<T, S>
where T: Debug,

1.16.0 · Source

impl<T, S> Debug for std::collections::hash::set::Intersection<'_, T, S>
where T: Debug + Eq + Hash, S: BuildHasher,

Source

impl<T, S> Debug for std::collections::hash::set::OccupiedEntry<'_, T, S>
where T: Debug,

1.16.0 · Source

impl<T, S> Debug for std::collections::hash::set::SymmetricDifference<'_, T, S>
where T: Debug + Eq + Hash, S: BuildHasher,

1.16.0 · Source

impl<T, S> Debug for std::collections::hash::set::Union<'_, T, S>
where T: Debug + Eq + Hash, S: BuildHasher,

Source

impl<T, S> Debug for std::collections::hash::set::VacantEntry<'_, T, S>
where T: Debug,



impl<T, S, A> Debug for Difference<'_, T, S, A>
where T: Debug + Eq + Hash, S: BuildHasher, A: Allocator,



impl<T, S, A> Debug for Entry<'_, T, S, A>
where T: Debug, A: Allocator,



impl<T, S, A> Debug for HashSet<T, S, A>
where T: Debug, A: Allocator,



impl<T, S, A> Debug for Intersection<'_, T, S, A>
where T: Debug + Eq + Hash, S: BuildHasher, A: Allocator,



impl<T, S, A> Debug for OccupiedEntry<'_, T, S, A>
where T: Debug, A: Allocator,



impl<T, S, A> Debug for SymmetricDifference<'_, T, S, A>
where T: Debug + Eq + Hash, S: BuildHasher, A: Allocator,



impl<T, S, A> Debug for Union<'_, T, S, A>
where T: Debug + Eq + Hash, S: BuildHasher, A: Allocator,



impl<T, S, A> Debug for VacantEntry<'_, T, S, A>
where T: Debug, A: Allocator,



impl<T, S, const N: usize> Debug for IndexSet<T, S, N>
where T: Eq + Hash + Debug, S: BuildHasher,



impl<T, Src, Dst> Debug for RigidTransform3D<T, Src, Dst>
where T: Debug,



impl<T, Src, Dst> Debug for Rotation2D<T, Src, Dst>
where T: Debug,



impl<T, Src, Dst> Debug for Rotation3D<T, Src, Dst>
where T: Debug,



impl<T, Src, Dst> Debug for Scale<T, Src, Dst>
where T: Debug,



impl<T, Src, Dst> Debug for Transform2D<T, Src, Dst>
where T: Copy + Debug + PartialEq + One + Zero,



impl<T, Src, Dst> Debug for Transform3D<T, Src, Dst>
where T: Copy + Debug + PartialEq + One + Zero,



impl<T, Src, Dst> Debug for Translation2D<T, Src, Dst>
where T: Debug,



impl<T, Src, Dst> Debug for Translation3D<T, Src, Dst>
where T: Debug,

1.0.0 · Source

impl<T, U> Debug for std::io::Chain<T, U>
where T: Debug, U: Debug,



impl<T, U> Debug for Box2D<T, U>
where T: Debug,



impl<T, U> Debug for Box3D<T, U>
where T: Debug,



impl<T, U> Debug for HomogeneousVector<T, U>
where T: Debug,



impl<T, U> Debug for Length<T, U>
where T: Debug,



impl<T, U> Debug for Point2D<T, U>
where T: Debug,



impl<T, U> Debug for Point3D<T, U>
where T: Debug,



impl<T, U> Debug for Rect<T, U>
where T: Debug,



impl<T, U> Debug for SideOffsets2D<T, U>
where T: Debug,



impl<T, U> Debug for Size2D<T, U>
where T: Debug,



impl<T, U> Debug for Size3D<T, U>
where T: Debug,



impl<T, U> Debug for Vector2D<T, U>
where T: Debug,



impl<T, U> Debug for Vector3D<T, U>
where T: Debug,

1.0.0 · Source

impl<T, const N: usize> Debug for [T; N]
where T: Debug,

1.40.0 · Source

impl<T, const N: usize> Debug for core::array::iter::IntoIter<T, N>
where T: Debug,

Source

impl<T, const N: usize> Debug for Mask<T, N>

Source

impl<T, const N: usize> Debug for Simd<T, N>



impl<T, const N: usize> Debug for Deque<T, N>
where T: Debug,



impl<T, const N: usize> Debug for HistoryBuffer<T, N>
where T: Debug,



impl<T, const N: usize> Debug for Queue<T, N>
where T: Debug,



impl<T, const N: usize> Debug for Vec<T, N>
where T: Debug,

1.0.0 · Source

impl<W> Debug for BufWriter<W>
where W: Write + Debug + ?Sized,

1.0.0 · Source

impl<W> Debug for LineWriter<W>
where W: Write + Debug + ?Sized,

1.0.0 · Source

impl<W> Debug for IntoInnerError<W>
where W: Debug,

Source

impl<Y, R> Debug for CoroutineState<Y, R>
where Y: Debug, R: Debug,



impl<const N: usize> Debug for String<N>